@@ -30,14 +30,37 @@
  ***************************************************************************/
 #ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif 
+#endif
+
+#include <GL/glew.h>
+
 #include "openglrenderer.h"
 #include "opengltexture.h"
 #include "CEGUIExceptions.h"
 #include "CEGUIEventArgs.h"
-#include "CEGUIImageCodec.h" 
+#include "CEGUIImageCodec.h"
 #include "CEGUIDynamicModule.h"
 
+#include <sstream>
+
+//Include the default codec for static builds
+#if defined(CEGUI_STATIC)
+#	if defined(CEGUI_CODEC_SILLY)
+#		include "../../ImageCodecModules/SILLYImageCodec/CEGUISILLYImageCodecModule.h"
+#	elif defined(CEGUI_CODEC_TGA)
+#		include "../../ImageCodecModules/TGAImageCodec/CEGUITGAImageCodecModule.h"
+#	elif defined(CEGUI_CODEC_CORONA)
+#		include "../../ImageCodecModules/CoronaImageCodec/CEGUICoronaImageCodecModule.h"
+#	elif defined(CEGUI_CODEC_DEVIL)
+#		include "../../ImageCodecModules/DevILImageCodec/CEGUIDevILImageCodecModule.h"
+#	elif defined(CEGUI_CODEC_FREEIMAGE)
+#		include "../../ImageCodecModules/FreeImageImageCodec/CEGUIFreeImageImageCodecModule.h"
+#	else //Make Silly the default
+#		include "../../ImageCodecModules/SILLYImageCodec/CEGUISILLYImageCodecModule.h"
+#	endif
+#endif
+
+
 #define S_(X) #X
 #define STRINGIZE(X) S_(X)
 
@@ -45,6 +68,27 @@
 // Start of CEGUI namespace section
 namespace CEGUI
 {
+//----------------------------------------------------------------------------//
+// The following are some GL extension / version dependant related items.
+// This is all done totally internally here; no need for external interface
+// to show any of this.
+//----------------------------------------------------------------------------//
+// we only really need this with MSVC / Windows(?) and by now it should already
+// be defined on that platform, so we just define it as empty macro so the
+// compile does not break on other systems.
+#ifndef APIENTRY
+#   define APIENTRY
+#endif
+//! Function to perform extentsions initialisation.
+void initialiseGLExtensions();
+//! Pointer to a function to use as glActiveTexture
+PFNGLACTIVETEXTUREPROC CEGUI_activeTexture;
+//! Pointer to a function to use as glClientActiveTexture
+PFNGLCLIENTACTIVETEXTUREPROC CEGUI_clientActiveTexture;
+//! Dummy function for if real ones are not present (saves testing each render)
+void APIENTRY activeTextureDummy(GLenum) {}
+//----------------------------------------------------------------------------//
+
 /*************************************************************************
 	Constants definitions
 *************************************************************************/
@@ -63,8 +107,8 @@ OpenGLRenderer::OpenGLRenderer(uint max_quads, ImageCodec*  codec) :
     d_imageCodec(codec),
     d_imageCodecModule(0)
 {
-	GLint vp[4];   
-    
+	GLint vp[4];
+
 	// initialise renderer size
 	glGetIntegerv(GL_VIEWPORT, vp);
 	glGetIntegerv(GL_MAX_TEXTURE_SIZE, &d_maxTextureSize);
@@ -75,18 +119,21 @@ OpenGLRenderer::OpenGLRenderer(uint max_quads, ImageCodec*  codec) :
 
     if (!d_imageCodec)
         setupImageCodec("");
+
     setModuleIdentifierString();
+
+    initialiseGLExtensions();
 }
 
 
 OpenGLRenderer::OpenGLRenderer(uint max_quads,int width, int height, ImageCodec* codec) :
 	d_queueing(true),
 	d_currTexture(0),
-	d_bufferPos(0), 
-    d_imageCodec(codec), 
+	d_bufferPos(0),
+    d_imageCodec(codec),
     d_imageCodecModule(0)
 {
-	GLint vp[4];   
+	GLint vp[4];
 
 	// initialise renderer size
 	glGetIntegerv(GL_VIEWPORT, vp);
@@ -95,9 +142,13 @@ OpenGLRenderer::OpenGLRenderer(uint max_quads,int width, int height, ImageCodec*
 	d_display_area.d_top	= 0;
 	d_display_area.d_right	= static_cast<float>(width);
 	d_display_area.d_bottom	= static_cast<float>(height);
+
     if (!d_imageCodec)
         setupImageCodec("");
+
     setModuleIdentifierString();
+
+    initialiseGLExtensions();
 }
 
 
@@ -161,19 +212,19 @@ void OpenGLRenderer::doRender(void)
 		const QuadInfo& quad = (*i);
 
 		if(d_currTexture != quad.texid)
-		{            
-			renderVBuffer();           
+		{
+			renderVBuffer();
 			glBindTexture(GL_TEXTURE_2D, quad.texid);
-			d_currTexture = quad.texid;          
+			d_currTexture = quad.texid;
 		}
 
-		//vert0       
+		//vert0
 		myBuff[d_bufferPos].vertex[0]	= quad.position.d_left;
 		myBuff[d_bufferPos].vertex[1]	= quad.position.d_top;
 		myBuff[d_bufferPos].vertex[2]	= quad.z;
 		myBuff[d_bufferPos].color		= quad.topLeftCol;
 		myBuff[d_bufferPos].tex[0]		= quad.texPosition.d_left;
-		myBuff[d_bufferPos].tex[1]		= quad.texPosition.d_top;         
+		myBuff[d_bufferPos].tex[1]		= quad.texPosition.d_top;
 		++d_bufferPos;
 
 		//vert1
@@ -195,7 +246,7 @@ void OpenGLRenderer::doRender(void)
             myBuff[d_bufferPos].vertex[2]	= quad.z;
             myBuff[d_bufferPos].color		= quad.bottomRightCol;
             myBuff[d_bufferPos].tex[0]		= quad.texPosition.d_right;
-            myBuff[d_bufferPos].tex[1]		= quad.texPosition.d_bottom;         
+            myBuff[d_bufferPos].tex[1]		= quad.texPosition.d_bottom;
         }
         // bottom-left to top-right diagonal
         else
@@ -205,7 +256,7 @@ void OpenGLRenderer::doRender(void)
             myBuff[d_bufferPos].vertex[2]	= quad.z;
             myBuff[d_bufferPos].color		= quad.topRightCol;
             myBuff[d_bufferPos].tex[0]		= quad.texPosition.d_right;
-            myBuff[d_bufferPos].tex[1]		= quad.texPosition.d_top;         
+            myBuff[d_bufferPos].tex[1]		= quad.texPosition.d_top;
         }
 		++d_bufferPos;
 
@@ -228,7 +279,7 @@ void OpenGLRenderer::doRender(void)
             myBuff[d_bufferPos].vertex[2]	= quad.z;
             myBuff[d_bufferPos].color		= quad.topLeftCol;
             myBuff[d_bufferPos].tex[0]		= quad.texPosition.d_left;
-            myBuff[d_bufferPos].tex[1]		= quad.texPosition.d_top;         
+            myBuff[d_bufferPos].tex[1]		= quad.texPosition.d_top;
         }
         // bottom-left to top-right diagonal
         else
@@ -238,7 +289,7 @@ void OpenGLRenderer::doRender(void)
             myBuff[d_bufferPos].vertex[2]	= quad.z;
             myBuff[d_bufferPos].color		= quad.bottomLeftCol;
             myBuff[d_bufferPos].tex[0]		= quad.texPosition.d_left;
-            myBuff[d_bufferPos].tex[1]		= quad.texPosition.d_bottom;         
+            myBuff[d_bufferPos].tex[1]		= quad.texPosition.d_bottom;
         }
 		++d_bufferPos;
 
@@ -248,11 +299,11 @@ void OpenGLRenderer::doRender(void)
 		myBuff[d_bufferPos].vertex[2]	= quad.z;
 		myBuff[d_bufferPos].color		= quad.bottomRightCol;
 		myBuff[d_bufferPos].tex[0]		= quad.texPosition.d_right;
-		myBuff[d_bufferPos].tex[1]		= quad.texPosition.d_bottom;         
+		myBuff[d_bufferPos].tex[1]		= quad.texPosition.d_bottom;
 		++d_bufferPos;
 
 		if(d_bufferPos > (VERTEXBUFFER_CAPACITY - VERTEX_PER_QUAD))
-		{          
+		{
 			renderVBuffer();
 		}
 
@@ -361,6 +412,9 @@ void OpenGLRenderer::initPerFrameStates(void)
 	glPushClientAttrib(GL_CLIENT_ALL_ATTRIB_BITS);
 	glPushAttrib(GL_ALL_ATTRIB_BITS);
 
+    CEGUI_activeTexture(GL_TEXTURE0);
+    CEGUI_clientActiveTexture(GL_TEXTURE0);
+
 	glPolygonMode(GL_FRONT, GL_FILL);
 	glMatrixMode(GL_PROJECTION);
 	glPushMatrix();
@@ -383,7 +437,7 @@ void OpenGLRenderer::initPerFrameStates(void)
 	glEnable(GL_CULL_FACE);
 
 	glEnable(GL_BLEND);
-	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA); 
+	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
 	glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
 	glEnable(GL_TEXTURE_2D);
@@ -392,9 +446,9 @@ void OpenGLRenderer::initPerFrameStates(void)
 
 void OpenGLRenderer::exitPerFrameStates(void)
 {
-	glPopMatrix(); 
+	glPopMatrix();
 	glMatrixMode(GL_PROJECTION);
-	glPopMatrix(); 
+	glPopMatrix();
 	glMatrixMode(GL_MODELVIEW);
 
 	//restore former attributes
@@ -466,7 +520,7 @@ void OpenGLRenderer::renderQuadDirect(const Rect& dest_rect, float z, const Text
 	myquad[1].vertex[0] = quad.position.d_left;
 	myquad[1].vertex[1] = quad.position.d_bottom;
 	myquad[1].vertex[2] = z;
-	myquad[1].color     = quad.bottomLeftCol;     
+	myquad[1].color     = quad.bottomLeftCol;
 	myquad[1].tex[0]    = quad.texPosition.d_left;
 	myquad[1].tex[1]    = quad.texPosition.d_bottom;
 
@@ -497,7 +551,7 @@ void OpenGLRenderer::renderQuadDirect(const Rect& dest_rect, float z, const Text
 	myquad[3].vertex[0] = quad.position.d_right;
 	myquad[3].vertex[1] = quad.position.d_top;
 	myquad[3].vertex[2] = z;
-	myquad[3].color     = quad.topRightCol;      
+	myquad[3].color     = quad.topRightCol;
 	myquad[3].tex[0]    = quad.texPosition.d_right;
 	myquad[3].tex[1]    = quad.texPosition.d_top;
 
@@ -557,7 +611,7 @@ uint32 OpenGLRenderer::colourToOGL(const colour& col) const
 
 
 /*************************************************************************
-	Set the size of the display in pixels.	
+	Set the size of the display in pixels.
 *************************************************************************/
 void OpenGLRenderer::setDisplaySize(const Size& sz)
 {
@@ -607,21 +661,21 @@ void OpenGLRenderer::restoreTextures()
     }
 }
 /***********************************************************************
-    Get the current ImageCodec object used 
+    Get the current ImageCodec object used
 ************************************************************************/
-ImageCodec& OpenGLRenderer::getImageCodec() 
+ImageCodec& OpenGLRenderer::getImageCodec()
 {
     return *d_imageCodec;
 }
 /***********************************************************************
-    Set the current ImageCodec object used 
+    Set the current ImageCodec object used
 ************************************************************************/
 void OpenGLRenderer::setImageCodec(const String& codecName)
 {
-    setupImageCodec(codecName);    
+    setupImageCodec(codecName);
 }
 /***********************************************************************
-    Set the current ImageCodec object used 
+    Set the current ImageCodec object used
 ************************************************************************/
 void OpenGLRenderer::setImageCodec(ImageCodec* codec)
 {
@@ -629,47 +683,72 @@ void OpenGLRenderer::setImageCodec(ImageCodec* codec)
     {
         cleanupImageCodec();
         d_imageCodec = codec;
-        d_imageCodecModule = 0; 
+        d_imageCodecModule = 0;
     }
 }
 /***********************************************************************
-    setup the ImageCodec object used 
+    setup the ImageCodec object used
 ************************************************************************/
 void OpenGLRenderer::setupImageCodec(const String& codecName)
 {
-    
-    // Cleanup the old image codec 
+
+    // Cleanup the old image codec
     if (d_imageCodec)
         cleanupImageCodec();
-    // Test whether we should use the default codec or not 
+
+    // Test whether we should use the default codec or not
     if (codecName.empty())
-        d_imageCodecModule = new DynamicModule(String("CEGUI") + d_defaultImageCodecName);
-    else 
+		//If we are statically linking the default codec will already be in the system
+#if defined(CEGUI_STATIC)
+		d_imageCodecModule = 0;
+#else
+		d_imageCodecModule = new DynamicModule(String("CEGUI") + d_defaultImageCodecName);
+#endif
+    else
         d_imageCodecModule = new DynamicModule(String("CEGUI") + codecName);
-    
-    // Create the codec object itself 
-    ImageCodec* (*createFunc)(void) = 
-        (ImageCodec* (*)(void))d_imageCodecModule->getSymbolAddress("createImageCodec");
-    d_imageCodec = createFunc();
+
+	//Check to make sure we have a module...
+	if(d_imageCodecModule)
+	{
+		// Create the codec object itself
+		ImageCodec* (*createFunc)(void) =
+			(ImageCodec* (*)(void))d_imageCodecModule->getSymbolAddress("createImageCodec");
+		d_imageCodec = createFunc();
+	} // if(d_imageCodecModule)
+	else
+	{
+#if defined(CEGUI_STATIC)
+		d_imageCodec = createImageCodec();
+#else
+		throw InvalidRequestException("Unable to load codec " + codecName);
+#endif
+	}
+
 }
 /***********************************************************************
-    cleanup the ImageCodec object used 
+    cleanup the ImageCodec object used
 ************************************************************************/
 void OpenGLRenderer::cleanupImageCodec()
 {
     if (d_imageCodec && d_imageCodecModule)
     {
-        void(*deleteFunc)(ImageCodec*) = 
+        void(*deleteFunc)(ImageCodec*) =
             (void(*)(ImageCodec*))d_imageCodecModule->getSymbolAddress("destroyImageCodec");
         deleteFunc(d_imageCodec);
         d_imageCodec = 0;
         delete d_imageCodecModule;
         d_imageCodecModule = 0;
-    }
-    
+    } // if (d_imageCodec && d_imageCodecModule)
+	else
+	{
+#if defined(CEGUI_STATIC)
+		destroyImageCodec(d_imageCodec);
+#endif
+	}
+
 }
 /***********************************************************************
-    set the default ImageCodec name 
+    set the default ImageCodec name
 ************************************************************************/
 void OpenGLRenderer::setDefaultImageCodecName(const String& codecName)
 {
@@ -677,19 +756,54 @@ void OpenGLRenderer::setDefaultImageCodecName(const String& codecName)
 }
 
 /***********************************************************************
-    get the default ImageCodec name to be used  
+    get the default ImageCodec name to be used
 ************************************************************************/
 const String& OpenGLRenderer::getDefaultImageCodecName()
 {
     return d_defaultImageCodecName;
-    
+
 }
 
 /***********************************************************************
     store the name of the default ImageCodec
 ************************************************************************/
-String OpenGLRenderer::d_defaultImageCodecName(STRINGIZE(CEGUI_DEFAULT_IMAGE_CODEC)); 
+String OpenGLRenderer::d_defaultImageCodecName(STRINGIZE(CEGUI_DEFAULT_IMAGE_CODEC));
 
+//----------------------------------------------------------------------------//
+void initialiseGLExtensions()
+{
+    // initialise GLEW
+    GLenum err = glewInit();
+    if (GLEW_OK != err)
+    {
+        std::ostringstream err_string;
+        err_string << "OpenGLRenderer failed to initialise the GLEW library. "
+            << glewGetErrorString(err);
+
+        throw RendererException(err_string.str());
+    }
+
+    // GL 1.3 has multi-texture support natively
+    if (GLEW_VERSION_1_3)
+    {
+        CEGUI_activeTexture = glActiveTexture;
+        CEGUI_clientActiveTexture = glClientActiveTexture;
+    }
+    // Maybe there is the ARB_multitexture extension version?
+    else if (GL_ARB_multitexture)
+    {
+        CEGUI_activeTexture = glActiveTextureARB;
+        CEGUI_clientActiveTexture = glClientActiveTextureARB;
+    }
+    // assign dummy functions if no multitexture possibilities
+    else
+    {
+        CEGUI_activeTexture = activeTextureDummy;
+        CEGUI_clientActiveTexture = activeTextureDummy;
+    }
+}
+
+//----------------------------------------------------------------------------//
 
 } // End of  CEGUI namespace section
 
