@@ -660,7 +660,9 @@ void DirectX81Renderer::postD3DReset(void)
 	// Recreate a vertex buffer
 	if (FAILED(d_device->CreateVertexBuffer((VERTEXBUFFER_CAPACITY * sizeof(QuadVertex)), D3DUSAGE_DYNAMIC|D3DUSAGE_WRITEONLY, VERTEX_FVF, D3DPOOL_DEFAULT, &d_buffer)))
 	{
-		throw RendererException("DirectX81Renderer::preD3DReset - Failed to create the VertexBuffer for use by the DirectX81Renderer object.");
+		throw RendererException("DirectX81Renderer::postD3DReset - Failed to "
+                                "create the VertexBuffer for use by the "
+                                "DirectX81Renderer object.");
 	}
 
 	// perform post-reset operations on all textures
