@@ -46,13 +46,6 @@
 #include "CEGUIDefaultResourceProvider.h"
 #include <stdexcept>
 
-#ifdef _MSC_VER
-# if defined(DEBUG) || defined (_DEBUG)
-#   pragma comment (lib, "DirectX9GUIRenderer_d.lib")
-# else
-#   pragma comment (lib, "DirectX9GUIRenderer.lib")
-# endif
-#endif
 
 /*************************************************************************
     Impl struct
@@ -92,15 +85,26 @@ CEGuiD3D9BaseApplication::CEGuiD3D9BaseApplication() :
                 CEGUI::DefaultResourceProvider* rp = static_cast<CEGUI::DefaultResourceProvider*>
                     (CEGUI::System::getSingleton().getResourceProvider());
 
-                rp->setResourceGroupDirectory("schemes", "../datafiles/schemes/");
-                rp->setResourceGroupDirectory("imagesets", "../datafiles/imagesets/");
-                rp->setResourceGroupDirectory("fonts", "../datafiles/fonts/");
-                rp->setResourceGroupDirectory("layouts", "../datafiles/layouts/");
-                rp->setResourceGroupDirectory("looknfeels", "../datafiles/looknfeel/");
-                rp->setResourceGroupDirectory("lua_scripts", "../datafiles/lua_scripts/");
-#if defined(CEGUI_WITH_XERCES) && (CEGUI_DEFAULT_XMLPARSER == XercesParser)
-                rp->setResourceGroupDirectory("schemas", "../../XMLRefSchema/");
-#endif
+                const char* dataPathPrefix = getDataPathPrefix();
+                char resourcePath[PATH_MAX];
+
+                // for each resource type, set a resource group directory
+                sprintf(resourcePath, "%s/%s", dataPathPrefix, "schemes/");
+                rp->setResourceGroupDirectory("schemes", resourcePath);
+                sprintf(resourcePath, "%s/%s", dataPathPrefix, "imagesets/");
+                rp->setResourceGroupDirectory("imagesets", resourcePath);
+                sprintf(resourcePath, "%s/%s", dataPathPrefix, "fonts/");
+                rp->setResourceGroupDirectory("fonts", resourcePath);
+                sprintf(resourcePath, "%s/%s", dataPathPrefix, "layouts/");
+                rp->setResourceGroupDirectory("layouts", resourcePath);
+                sprintf(resourcePath, "%s/%s", dataPathPrefix, "looknfeel/");
+                rp->setResourceGroupDirectory("looknfeels", resourcePath);
+                sprintf(resourcePath, "%s/%s", dataPathPrefix, "lua_scripts/");
+                rp->setResourceGroupDirectory("lua_scripts", resourcePath);
+                #if defined(CEGUI_WITH_XERCES) && (CEGUI_DEFAULT_XMLPARSER == XercesParser)
+                    sprintf(resourcePath, "%s/%s", dataPathPrefix, "XMLRefSchema/");
+                    rp->setResourceGroupDirectory("schemas", resourcePath);
+                #endif
 
                 CEGUI::Logger::getSingleton().setLoggingLevel(CEGUI::Informative);
 
@@ -163,6 +167,15 @@ bool CEGuiD3D9BaseApplication::execute(CEGuiSample* sampleApp)
     {
         if (idle)
         {
+            CEGUI::System& guiSystem = CEGUI::System::getSingleton();
+
+            // do time based updates
+            DWORD thisTime = GetTickCount();
+            float elapsed = static_cast<float>(thisTime - d_lastFrameTime);
+            d_lastFrameTime = thisTime;
+            // inject the time pulse
+            guiSystem.injectTimePulse(elapsed / 1000.0f);
+
             // handle D3D lost device stuff
             coop = pimpl->d_3DDevice->TestCooperativeLevel();
 
@@ -191,7 +204,6 @@ bool CEGuiD3D9BaseApplication::execute(CEGuiSample* sampleApp)
             Win32AppHelper::doDirectInputEvents(pimpl->d_directInput);
 
             // draw display
-			CEGUI::System& guiSystem = CEGUI::System::getSingleton();
             pimpl->d_3DDevice->Clear(0, 0, D3DCLEAR_TARGET, D3DCOLOR_XRGB(0, 0, 0), 1.0f, 0);
             guiSystem.renderGUI();
 
