@@ -4,7 +4,7 @@
     author:     Paul D Turner
 *************************************************************************/
 /***************************************************************************
- *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *   Copyright (C) 2004 - 2008 Paul D Turner & The CEGUI Development Team
  *
  *   Permission is hereby granted, free of charge, to any person obtaining
  *   a copy of this software and associated documentation files (the
@@ -29,6 +29,10 @@
 #   include "config.h"
 #endif
 
+#ifdef __linux__
+# include <unistd.h>
+#endif
+
 // this controls conditional compile of file for Apple
 #include "CEGUISamplesConfig.h"
 #ifdef CEGUI_SAMPLES_USE_IRRLICHT
@@ -69,15 +73,26 @@ CEGuiIrrlichtBaseApplication::CEGuiIrrlichtBaseApplication() :
     CEGUI::DefaultResourceProvider* rp = static_cast<CEGUI::DefaultResourceProvider*>
         (CEGUI::System::getSingleton().getResourceProvider());
 
-    rp->setResourceGroupDirectory("schemes", "../datafiles/schemes/");
-    rp->setResourceGroupDirectory("imagesets", "../datafiles/imagesets/");
-    rp->setResourceGroupDirectory("fonts", "../datafiles/fonts/");
-    rp->setResourceGroupDirectory("layouts", "../datafiles/layouts/");
-    rp->setResourceGroupDirectory("looknfeels", "../datafiles/looknfeel/");
-    rp->setResourceGroupDirectory("lua_scripts", "../datafiles/lua_scripts/");
-#if defined(CEGUI_WITH_XERCES) && (CEGUI_DEFAULT_XMLPARSER == XercesParser)
-    rp->setResourceGroupDirectory("schemas", "../../XMLRefSchema/");
-#endif
+    const char* dataPathPrefix = getDataPathPrefix();
+    char resourcePath[PATH_MAX];
+
+    // for each resource type, set a resource group directory
+    sprintf(resourcePath, "%s/%s", dataPathPrefix, "schemes/");
+    rp->setResourceGroupDirectory("schemes", resourcePath);
+    sprintf(resourcePath, "%s/%s", dataPathPrefix, "imagesets/");
+    rp->setResourceGroupDirectory("imagesets", resourcePath);
+    sprintf(resourcePath, "%s/%s", dataPathPrefix, "fonts/");
+    rp->setResourceGroupDirectory("fonts", resourcePath);
+    sprintf(resourcePath, "%s/%s", dataPathPrefix, "layouts/");
+    rp->setResourceGroupDirectory("layouts", resourcePath);
+    sprintf(resourcePath, "%s/%s", dataPathPrefix, "looknfeel/");
+    rp->setResourceGroupDirectory("looknfeels", resourcePath);
+    sprintf(resourcePath, "%s/%s", dataPathPrefix, "lua_scripts/");
+    rp->setResourceGroupDirectory("lua_scripts", resourcePath);
+    #if defined(CEGUI_WITH_XERCES) && (CEGUI_DEFAULT_XMLPARSER == XercesParser)
+        sprintf(resourcePath, "%s/%s", dataPathPrefix, "XMLRefSchema/");
+        rp->setResourceGroupDirectory("schemas", resourcePath);
+    #endif
 
     irr::scene::ICameraSceneNode* camera = d_smgr->addCameraSceneNode(0, core::vector3df(0,0,0), core::vector3df(0,0,1));
     camera->setFOV(1.56f);
@@ -106,16 +121,25 @@ bool CEGuiIrrlichtBaseApplication::execute(CEGuiSample* sampleApp)
 {
     sampleApp->initialiseSample();
 
+    CEGUI::System& guiSystem = CEGUI::System::getSingleton();
+
     // draw everything
     while(d_device->run())
     {
         // draw only if the window is active
         if (d_device->isWindowActive())
         {
+            checkWindowResize();
+
+            // create FPS string
+            char fps_buff[16];
+            int frame_rate = d_driver->getFPS();
+            sprintf(fps_buff , "FPS: %d", frame_rate);
+
             // calculate time elapsed
             irr::u32 currTime = d_device->getTimer()->getRealTime();
             // inject time pulse
-            CEGUI::System::getSingleton().injectTimePulse(static_cast<float>(currTime - d_lastTime) / 1000.0f);
+            guiSystem.injectTimePulse(static_cast<float>(currTime - d_lastTime) / 1000.0f);
             d_lastTime = currTime;
 
             // start rendering
@@ -123,7 +147,16 @@ bool CEGuiIrrlichtBaseApplication::execute(CEGuiSample* sampleApp)
             //draw scene
             d_smgr->drawAll();
             // draw gui
-            CEGUI::System::getSingleton().renderGUI();
+            guiSystem.renderGUI();
+            // render FPS
+            CEGUI::Font* fnt = guiSystem.getDefaultFont();
+            if (fnt)
+            {
+                guiSystem.getRenderer()->setQueueingEnabled(false);
+                fnt->drawText(fps_buff, CEGUI::Vector3(0, 0, 0),
+                    guiSystem.getRenderer()->getRect());
+            }
+
             d_driver->endScene();
         }
 
@@ -140,7 +173,11 @@ void CEGuiIrrlichtBaseApplication::cleanup()
     // Nothing to do here.
 }
 
+#if CEGUI_IRR_SDK_VERSION >= 14
+bool CEGuiIrrlichtBaseApplication::OnEvent(const irr::SEvent& event)
+#else
 bool CEGuiIrrlichtBaseApplication::OnEvent(irr::SEvent event)
+#endif
 {
     // cegui samples always quit on escape
     if (event.EventType == irr::EET_KEY_INPUT_EVENT)
@@ -155,5 +192,11 @@ bool CEGuiIrrlichtBaseApplication::OnEvent(irr::SEvent event)
     return (d_renderer != 0) ? d_renderer->OnEvent(event) : false;
 }
 
+void CEGuiIrrlichtBaseApplication::checkWindowResize()
+{
+    irr::core::dimension2d<irr::s32> cur_size = d_driver->getScreenSize();
+    d_renderer->setDisplaySize(CEGUI::Size(cur_size.Width, cur_size.Height));
+}
+
 #endif
 
