@@ -4,7 +4,7 @@
     author:     Paul D Turner
 *************************************************************************/
 /***************************************************************************
- *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *   Copyright (C) 2004 - 2008 Paul D Turner & The CEGUI Development Team
  *
  *   Permission is hereby granted, free of charge, to any person obtaining
  *   a copy of this software and associated documentation files (the
@@ -29,6 +29,10 @@
 #   include "config.h"
 #endif
 
+#ifdef __linux__
+# include <unistd.h>
+#endif
+
 // this controls conditional compile of file for Apple
 #include "CEGUISamplesConfig.h"
 #ifdef CEGUI_SAMPLES_USE_OPENGL
@@ -44,6 +48,9 @@
 #include <OpenGL/gl.h>
 #include <OpenGL/glu.h>
 #else
+#ifdef __MINGW32__
+#define GLUT_DISABLE_ATEXIT_HACK
+#endif
 #include <GL/glut.h>
 #ifdef __FREEGLUT_STD_H__
 #   include <GL/freeglut_ext.h>
@@ -53,13 +60,20 @@
 #endif
 
 #include <stdexcept>
-#include <stdlib.h>
 
 #ifdef _MSC_VER
 # if defined(DEBUG) || defined (_DEBUG)
-#   pragma comment (lib, "OpenGLGUIRenderer_d.lib")
+#	if defined(CEGUI_STATIC)
+#		pragma comment (lib, "OpenGLGUIRenderer_Static_d.lib")
+#	else
+#		pragma comment (lib, "OpenGLGUIRenderer_d.lib")
+#	endif
 # else
-#   pragma comment (lib, "OpenGLGUIRenderer.lib")
+#	if defined(CEGUI_STATIC)
+#		pragma comment (lib, "OpenGLGUIRenderer_Static.lib")
+#	else
+#		pragma comment (lib, "OpenGLGUIRenderer.lib")
+#	endif
 # endif
 #endif
 
@@ -118,10 +132,10 @@ CEGuiOpenGLBaseApplication::CEGuiOpenGLBaseApplication()
 {
     // fake args for glutInit
     int argc = 1;
-    char* argv = "SampleApp";
+    const char* argv = "SampleApp";
 
     // Do GLUT init
-    glutInit(&argc, &argv);
+    glutInit(&argc, (char**)&argv);
     glutInitDisplayMode(GLUT_DEPTH|GLUT_DOUBLE|GLUT_RGBA);
     glutInitWindowSize(800, 600);
     glutInitWindowPosition(100, 100);
@@ -150,14 +164,37 @@ CEGuiOpenGLBaseApplication::CEGuiOpenGLBaseApplication()
     CEGUI::DefaultResourceProvider* rp = static_cast<CEGUI::DefaultResourceProvider*>
         (CEGUI::System::getSingleton().getResourceProvider());
 
-    rp->setResourceGroupDirectory("schemes", "../datafiles/schemes/");
-    rp->setResourceGroupDirectory("imagesets", "../datafiles/imagesets/");
-    rp->setResourceGroupDirectory("fonts", "../datafiles/fonts/");
-    rp->setResourceGroupDirectory("layouts", "../datafiles/layouts/");
-    rp->setResourceGroupDirectory("looknfeels", "../datafiles/looknfeel/");
-    rp->setResourceGroupDirectory("lua_scripts", "../datafiles/lua_scripts/");
-#if defined(CEGUI_WITH_XERCES) && (CEGUI_DEFAULT_XMLPARSER == XercesParser)
-    rp->setResourceGroupDirectory("schemas", "../../XMLRefSchema/");
+#ifndef __APPLE__
+    const char* dataPathPrefix = getDataPathPrefix();
+    char resourcePath[PATH_MAX];
+
+    // for each resource type, set a resource group directory
+    sprintf(resourcePath, "%s/%s", dataPathPrefix, "schemes/");
+    rp->setResourceGroupDirectory("schemes", resourcePath);
+    sprintf(resourcePath, "%s/%s", dataPathPrefix, "imagesets/");
+    rp->setResourceGroupDirectory("imagesets", resourcePath);
+    sprintf(resourcePath, "%s/%s", dataPathPrefix, "fonts/");
+    rp->setResourceGroupDirectory("fonts", resourcePath);
+    sprintf(resourcePath, "%s/%s", dataPathPrefix, "layouts/");
+    rp->setResourceGroupDirectory("layouts", resourcePath);
+    sprintf(resourcePath, "%s/%s", dataPathPrefix, "looknfeel/");
+    rp->setResourceGroupDirectory("looknfeels", resourcePath);
+    sprintf(resourcePath, "%s/%s", dataPathPrefix, "lua_scripts/");
+    rp->setResourceGroupDirectory("lua_scripts", resourcePath);
+    #if defined(CEGUI_WITH_XERCES) && (CEGUI_DEFAULT_XMLPARSER == XercesParser)
+        sprintf(resourcePath, "%s/%s", dataPathPrefix, "XMLRefSchema/");
+        rp->setResourceGroupDirectory("schemas", resourcePath);
+    #endif
+#else
+    rp->setResourceGroupDirectory("schemes", "datafiles/schemes/");
+    rp->setResourceGroupDirectory("imagesets", "datafiles/imagesets/");
+    rp->setResourceGroupDirectory("fonts", "datafiles/fonts/");
+    rp->setResourceGroupDirectory("layouts", "datafiles/layouts/");
+    rp->setResourceGroupDirectory("looknfeels", "datafiles/looknfeel/");
+    rp->setResourceGroupDirectory("lua_scripts", "datafiles/lua_scripts/");
+    #if defined(CEGUI_WITH_XERCES) && (CEGUI_DEFAULT_XMLPARSER == XercesParser)
+        rp->setResourceGroupDirectory("schemas", "XMLRefSchema/");
+    #endif
 #endif
 }
 
