@@ -4,7 +4,7 @@
     author:     Paul D Turner
 *************************************************************************/
 /***************************************************************************
- *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *   Copyright (C) 2004 - 2008 Paul D Turner & The CEGUI Development Team
  *
  *   Permission is hereby granted, free of charge, to any person obtaining
  *   a copy of this software and associated documentation files (the
@@ -52,7 +52,7 @@ Win32CEGuiRendererSelector::~Win32CEGuiRendererSelector()
 /*************************************************************************
     Display the dialog and wait for user
 *************************************************************************/
-bool Win32CEGuiRendererSelector::inkokeDialog()
+bool Win32CEGuiRendererSelector::invokeDialog()
 {
     // dialog template was not created so abort.
     if (!d_template)
@@ -394,6 +394,7 @@ INT_PTR CALLBACK Win32CEGuiRendererSelector::dialogProcedure(HWND hDlg, UINT mes
                 obj->addComboboxOption(combo, "Ogre Engine Renderer", OgreGuiRendererType);
                 obj->addComboboxOption(combo, "Microsoft Direct3D 8.1 Renderer", Direct3D81GuiRendererType);
                 obj->addComboboxOption(combo, "Microsoft Direct3D 9 Renderer", Direct3D9GuiRendererType);
+                obj->addComboboxOption(combo, "Microsoft Direct3D 10 Renderer", Direct3D10GuiRendererType);
                 obj->addComboboxOption(combo, "OpenGL Renderer", OpenGLGuiRendererType);
                 obj->addComboboxOption(combo, "Irrlicht Engine Renderer", IrrlichtGuiRendererType);
             }
