@@ -2,7 +2,7 @@
 	filename: required.h
 	created:  16/3/2005
 	author:   Tomas Lindquist Olsen
-	
+
 	purpose:  Header that includes the necessary stuff needed for the Lua bindings
 *************************************************************************/
 /***************************************************************************
@@ -38,6 +38,9 @@
 
 #define LuaFunctorSubscribeEvent CEGUI::LuaFunctor::SubscribeEvent
 
+//This is used to keep compilers happy
+#define CEGUIDeadException(e) &
+
 #if defined(_MSC_VER) && !defined(snprintf)
 #   define snprintf   _snprintf
 #endif
@@ -47,7 +50,19 @@ typedef CEGUI::String string;
 namespace CEGUI
 {
 
-typedef Event::Connection EventConnection;
+/*************************************************************************
+    Helper class to enable us to represent an Event::Connection object
+    (which is actually a RefCounted<BoundSlot> object)
+*************************************************************************/
+class EventConnection
+{
+    RefCounted<BoundSlot> d_slot;
+
+public:
+    EventConnection(RefCounted<BoundSlot> slot);
+    bool connected() const;
+    void disconnect();
+};
 
 /*************************************************************************
 	Functions for getting Thumb range pairs as two return values
