@@ -169,10 +169,17 @@ namespace CEGUI
         if (res == XMLTransService::Ok)
         {
             String out;
+#if _XERCES_VERSION >= 30000
+            XMLByte outBuff[128];
+            XMLSize_t outputLength;
+            XMLSize_t eaten = 0;
+            XMLSize_t offset = 0;
+#else /* _XERCES_VERSION >= 30000 */
             utf8 outBuff[128];
             unsigned int outputLength;
             unsigned int eaten = 0;
             unsigned int offset = 0;
+#endif /* _XERCES_VERSION >= 30000 */
 //            unsigned int inputLength = XMLString::stringLen(xmlch_str); // dalfy caracters node need to transcode but give the size 
 
             while (inputLength)
