@@ -1,31 +1,35 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIBase.h
 	created:	20/2/2004
 	author:		Paul D Turner
-	
+
 	purpose:	Base include used within the system
 				This contains various lower level bits required
-				by other parts of the system.  All other library 
+				by other parts of the system.  All other library
 				headers will include this file.
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #ifndef _CEGUIBase_h_
 #define _CEGUIBase_h_
 
@@ -41,7 +45,7 @@
 	Dynamic Library import / export control conditional
 	(Define CEGUIBASE_EXPORTS to export symbols, else they are imported)
 *************************************************************************/
-#if defined( __WIN32__ ) || defined( _WIN32 )
+#if (defined( __WIN32__ ) || defined( _WIN32 )) && !defined(CEGUI_STATIC)
 #   ifdef CEGUIBASE_EXPORTS
 #       define CEGUIEXPORT __declspec(dllexport)
 #   else
@@ -63,17 +67,17 @@
 // Detect macros for min / max and undefine (with a warning where possible)
 #if defined(max)
 #   if defined(_MSC_VER)
-#       pragma message("Macro defintion of max detected - undefining")
+#       pragma message("Macro definition of max detected - undefining")
 #   elif defined (__GNUC__)
-#       warning ("Macro defintion of max detected - undefining")
+#       warning ("Macro definition of max detected - undefining")
 #   endif
 #   undef max
 #endif
 #if defined(min)
 #   if defined(_MSC_VER)
-#       pragma message("Macro defintion of min detected - undefining")
+#       pragma message("Macro definition of min detected - undefining")
 #   elif defined (__GNUC__)
-#       warning ("Macro defintion of min detected - undefining")
+#       warning ("Macro definition of min detected - undefining")
 #   endif
 #   undef min
 #endif
@@ -101,7 +105,6 @@
 #    define ceguimax	std::max
 #endif
 
-
 /*************************************************************************
 	Documentation for the CEGUI namespace itself
 *************************************************************************/
@@ -142,6 +145,13 @@ typedef std::ostream OutStream;     //!< Output stream class.
 }  // end of CEGUI namespace section
 
 
+//////////////////////////////////////////////////////////////////////////
+// Comment this line to remove the alignment of elements to pixel
+// boundaries.  This may give you a performance boost at the expense
+// of visual quality
+//////////////////////////////////////////////////////////////////////////
+#define CEGUI_ALIGN_ELEMENTS_TO_PIXELS 1
+
 /*!
 \brief
 	Macro used to return a float value rounded to the nearest integer.
@@ -156,7 +166,7 @@ typedef std::ostream OutStream;     //!< Output stream class.
 	\a x after having been rounded
 */
 #if defined(CEGUI_ALIGN_ELEMENTS_TO_PIXELS)
-#	define PixelAligned(x)	( (float)(int)(( x ) + 0.5f) )
+#	define PixelAligned(x)	( (float)(int)(( x ) + (( x ) > 0.0f ? 0.5f : -0.5f)) )
 #else
 #	define PixelAligned(x)	( x )
 #endif
