@@ -1,26 +1,30 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIDragContainer.h
 	created:	14/2/2005
 	author:		Paul D Turner
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #ifndef _CEGUIDragContainer_h_
 #define _CEGUIDragContainer_h_
 
@@ -246,15 +250,6 @@ namespace CEGUI
         /*************************************************************************
         	Protected Implementation Methods
         *************************************************************************/
-        /*!
-        \brief
-            Adds events specific to the DragContainer base class.
-        
-        \return
-            Nothing.
-        */
-        void addDragContainerEvents(void);
-
         /*!
         \brief
             Return whether the required minimum movement threshold before initiating dragging
@@ -299,7 +294,7 @@ namespace CEGUI
 
 		/*!
 		\brief
-			Return whether this window was inherited from the given class name at some point in the inheritance heirarchy.
+			Return whether this window was inherited from the given class name at some point in the inheritance hierarchy.
 
 		\param class_name
 			The class name that is to be checked.
@@ -309,16 +304,11 @@ namespace CEGUI
 		*/
 		virtual bool	testClassName_impl(const String& class_name) const
 		{
-			if (class_name==(const utf8*)"DragContainer")	return true;
+			if (class_name=="DragContainer")	return true;
 			return Window::testClassName_impl(class_name);
 		}
 
 
-        /*************************************************************************
-        	Implementation of abstract methods in Window
-        *************************************************************************/
-        void drawSelf(float z);
-
         /*************************************************************************
         	Overrides of methods in Window
         *************************************************************************/
@@ -332,6 +322,7 @@ namespace CEGUI
         virtual void onCaptureLost(WindowEventArgs& e);
         virtual void onAlphaChanged(WindowEventArgs& e);
         virtual void onClippingChanged(WindowEventArgs& e);/*Window::drawSelf(z);*/
+        virtual void onMoved(WindowEventArgs& e);
 
         /*************************************************************************
         	New Event handler methods
@@ -435,14 +426,15 @@ namespace CEGUI
         bool    d_draggingEnabled;  //!< True when dragging is enabled.
         bool    d_leftMouseDown;    //!< True when left mouse button is down.
         bool    d_dragging;         //!< true when being dragged.
-        Point   d_dragPoint;        //!< point we are being dragged at.
-        Point   d_startPosition;    //!< position prior to dragging.
+        UVector2 d_dragPoint;       //!< point we are being dragged at.
+        UVector2 d_startPosition;   //!< position prior to dragging.
         float   d_dragThreshold;    //!< Pixels mouse must move before dragging commences.
         float   d_dragAlpha;        //!< Alpha value to set when dragging.
         float   d_storedAlpha;      //!< Alpha value to re-set when dragging ends.
         bool    d_storedClipState;  //!< Parent clip state to re-set.
         Window* d_dropTarget;       //!< Target window for possible drop operation.
         const Image* d_dragCursorImage; //!< Image to use for mouse cursor when dragging.
+        bool d_dropflag;            //!< True when we're being dropped
 
     private:
         /*************************************************************************
@@ -466,31 +458,6 @@ namespace CEGUI
         void addDragContainerProperties(void);
     };
 
-    /*!
-    \brief
-        Factory class for producing DragContainer windows
-    */
-    class DragContainerFactory : public WindowFactory
-    {
-    public:
-        DragContainerFactory(void) : WindowFactory(DragContainer::WidgetTypeName) { }
-        ~DragContainerFactory(void){}
-
-        Window* createWindow(const String& name)
-        {
-            DragContainer* wnd = new DragContainer(d_type, name);
-            return wnd;
-        }
-
-        void destroyWindow(Window* window)
-        {
-            if (window->getType() == d_type)
-                delete window;
-        }
-
-    };
-
-
 } // End of  CEGUI namespace section
 
 
