@@ -1,28 +1,32 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIFrameWindow.h
 	created:	13/4/2004
 	author:		Paul D Turner
 	
 	purpose:	Interface to base class for FrameWindow
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #ifndef _CEGUIFrameWindow_h_
 #define _CEGUIFrameWindow_h_
 
@@ -48,7 +52,7 @@ class CEGUIEXPORT FrameWindow : public Window
 {
 public:
 	static const String EventNamespace;				//!< Namespace for global events
-
+    static const String WidgetTypeName;             //!< Window factory name
 
 	/*************************************************************************
 		Constants	
@@ -60,6 +64,12 @@ public:
 	// other bits
 	static const float	DefaultSizingBorderSize;	//!< Default size for the sizing border (in pixels)
 
+    /*************************************************************************
+        Child Widget name suffix constants
+    *************************************************************************/
+    static const String TitlebarNameSuffix;      //!< Widget name suffix for the titlebar component.
+    static const String CloseButtonNameSuffix;   //!< Widget name suffix for the close button component.
+
 
 	/*!
 	\brief
@@ -87,7 +97,7 @@ public:
 	\return
 		Nothing
 	*/
-	virtual void	initialise(void);
+	virtual void	initialiseComponents(void);
 	
 	
 	/*!
@@ -117,7 +127,7 @@ public:
 	\return
 		true if the window has a title bar and it is enabled, false if the window has no title bar or if the title bar is disabled.
 	*/	
-	bool	isTitleBarEnabled(void) const				{return (d_titlebar != NULL) && !((Window*)d_titlebar)->isDisabled();}
+	bool	isTitleBarEnabled(void) const;
 
 
 	/*!
@@ -127,7 +137,7 @@ public:
 	\return
 		true if the window has a close button and it is enabled, false if the window either has no close button or if the close button is disabled.
 	*/
-	bool	isCloseButtonEnabled(void) const			{return (d_closeButton != NULL) && !((Window*)d_closeButton)->isDisabled();}
+	bool	isCloseButtonEnabled(void) const;
 
 
 	/*!
@@ -248,32 +258,6 @@ public:
 	void	setSizingBorderThickness(float pixels)		{d_borderSize = pixels;}
 
 
-	/*!
-	\brief
-		Set the font to use for the title bar text
-
-	\param name
-		String object holding the name of the font to use.
-
-	\return
-		Nothing.
-	*/
-	void	setTitlebarFont(const String& name);
-
-
-	/*!
-	\brief
-		Set the font to use for the title bar text
-
-	\param font
-		Pointer to the font to use.
-
-	\return
-		Nothing.
-	*/
-	void	setTitlebarFont(Font* font);
-
-
 	/*!
 	\brief
 		Move the window by the pixel offsets specified in \a offset.
@@ -312,38 +296,6 @@ public:
 	void	setDragMovingEnabled(bool setting);
 
 
-	/*!
-	\brief
-		Return the font being used for the title bar text
-
-	\return
-		Pointer to the Font being used for the TitleBar on this FrameWindow.
-	*/
-	const Font*	getTitlebarFont(void) const;
-
-
-	/*!
-	\brief
-		Return the current colour used for rendering the caption text
-
-	\return
-		colour value that specifies the colour used when rendering the title bar caption text.
-	*/
-	colour	getCaptionColour(void) const;
-
-
-	/*!
-	\brief
-		Sets the colour to be used for rendering the caption text.
-
-	\param col
-		colour value that specifies the colour to be used when rendering the title bar caption text.
-
-	\return
-		Nothing.
-	*/
-	void	setCaptionColour(colour col);
-
     /*!
     \brief
         Return a pointer to the currently set Image to be used for the north-south
@@ -503,6 +455,30 @@ public:
     // overridden from Window class
     bool    isHit(const Point& position) const      { return Window::isHit(position) && !d_rolledup; }
 
+    /*!
+    \brief
+        Return a pointer to the Titlebar component widget for this FrameWindow.
+
+    \return
+        Pointer to a Titlebar object.
+
+    \exception UnknownObjectException
+        Thrown if the Titlebar component does not exist.
+    */
+    Titlebar* getTitlebar() const;
+
+    /*!
+    \brief
+        Return a pointer to the close button component widget for this
+        FrameWindow.
+
+    \return
+        Pointer to a PushButton object.
+
+    \exception UnknownObjectException
+        Thrown if the close button component does not exist.
+    */
+    PushButton* getCloseButton() const;
 
 	/*************************************************************************
 		Construction / Destruction
@@ -524,32 +500,6 @@ protected:
 	/*************************************************************************
 		Implementation Functions
 	*************************************************************************/
-	/*!
-	\brief
-		Create a control based upon the Titlebar base class to be used as the title bar for this window.
-
-    \param name
-        String object holding the name that must be used when creating the titlebar.
-
-	\return
-		Pointer to an object who's class derives from Titlebar
-	*/
-	virtual Titlebar*	createTitlebar(const String& name) const		= 0;
-
-
-	/*!
-	\brief
-		Create a control based upon the PushButton base class, to be used at the close button for the window.
-
-    \param name
-        String object holding the name that must be used when creating the close button.
-
-	\return
-		Pointer to an object who's class derives from PushButton.
-	*/
-	virtual PushButton*	createCloseButton(const String& name) const	= 0;
-
-
 	/*!
 	\brief
 		move the window's left edge by 'delta'.  The rest of the window does not move, thus this changes the size of the Window.
@@ -658,13 +608,6 @@ protected:
 	bool	isBottomSizingLocation(SizingLocation loc) const		{return ((loc == SizingBottom) || (loc == SizingBottomLeft) || (loc == SizingBottomRight));}
 
 
-	/*!
-	\brief
-		Add frame window specific events
-	*/
-	void	addFrameWindowEvents(void);
-
-
 	/*!
 	\brief
 		Method to respond to close button click events and fire our close event
@@ -683,12 +626,12 @@ protected:
 	\brief
 		Return a Rect that describes, in window relative pixel co-ordinates, the outer edge of the sizing area for this window.
 	*/
-	virtual	Rect	getSizingRect(void) const		{return Rect(0, 0, getAbsoluteWidth(), getAbsoluteHeight());}
+	virtual	Rect	getSizingRect(void) const		{return Rect(0, 0, d_pixelSize.d_width, d_pixelSize.d_height);}
 
 
 	/*!
 	\brief
-		Return whether this window was inherited from the given class name at some point in the inheritance heirarchy.
+		Return whether this window was inherited from the given class name at some point in the inheritance hierarchy.
 
 	\param class_name
 		The class name that is to be checked.
@@ -698,7 +641,7 @@ protected:
 	*/
 	virtual bool	testClassName_impl(const String& class_name) const
 	{
-		if (class_name==(const utf8*)"FrameWindow")	return true;
+		if (class_name=="FrameWindow")	return true;
 		return Window::testClassName_impl(class_name);
 	}
 
@@ -749,10 +692,6 @@ protected:
 	float	d_borderSize;		//!< thickness of the sizing border around this window
 	Point	d_dragPoint;		//!< point window is being dragged at.
 
-	// composite controls
-	Titlebar*	d_titlebar;				//!< points to the title bar widget.
-	PushButton*	d_closeButton;			//!< points to close button widget.
-
 	// images for cursor when on sizing border
 	const Image*	d_nsSizingCursor;		//!< North/South sizing cursor image.
 	const Image*	d_ewSizingCursor;		//!< East/West sizing cursor image.
@@ -774,8 +713,6 @@ private:
 	static FrameWindowProperties::RollUpEnabled		d_rollUpEnabledProperty;
 	static FrameWindowProperties::DragMovingEnabled	d_dragMovingEnabledProperty;
 	static FrameWindowProperties::SizingBorderThickness d_sizingBorderThicknessProperty;
-	static FrameWindowProperties::TitlebarFont		d_titlebarFontProperty;
-	static FrameWindowProperties::CaptionColour		d_captionColourProperty;
     static FrameWindowProperties::NSSizingCursorImage   d_nsSizingCursorProperty;
     static FrameWindowProperties::EWSizingCursorImage   d_ewSizingCursorProperty;
     static FrameWindowProperties::NWSESizingCursorImage d_nwseSizingCursorProperty;
