@@ -1,28 +1,32 @@
-/************************************************************************
+/***********************************************************************
     filename:   CEGUIGUISheet.h
     created:    5/6/2004
     author:     Paul D Turner
 
     purpose:    Interface to a default window
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #ifndef _CEGUIGUISheet_h_
 #define _CEGUIGUISheet_h_
 
@@ -61,7 +65,7 @@ public:
     \brief
         Constructor for GUISheet windows.
     */
-    GUISheet(const String& type, const String& name) : Window(type, name) {}
+    GUISheet(const String& type, const String& name);
 
 
     /*!
@@ -72,35 +76,9 @@ public:
 
 
 protected:
-    /*!
-    \brief
-        Perform the actual rendering for this Window.
-
-    \param z
-        float value specifying the base Z co-ordinate that should be used when rendering
-
-    \return
-        Nothing
-    */
-    virtual void    drawSelf(float z) {}
-
-
-    /*!
-    \brief
-        overridden initialise member to set-up our default state.
-    */
-    void initialise(void)
-    {
-        Window::initialise();
-
-        setMaximumSize(Size(1.0f, 1.0f));
-        setSize(Size(1.0f, 1.0f));
-    }
-
-
 	/*!
 	\brief
-		Return whether this window was inherited from the given class name at some point in the inheritance heirarchy.
+		Return whether this window was inherited from the given class name at some point in the inheritance hierarchy.
 
 	\param class_name
 		The class name that is to be checked.
@@ -110,55 +88,12 @@ protected:
 	*/
 	virtual bool	testClassName_impl(const String& class_name) const
 	{
-		if (class_name==(const utf8*)"GUISheet")	return true;
+		if (class_name=="DefaultWindow" || class_name=="GUISheet")	return true;
 		return Window::testClassName_impl(class_name);
 	}
 };
 
 
-/*!
-\brief
-    Factory class for producing default windows
-*/
-class GUISheetFactory : public WindowFactory
-{
-public:
-    /*************************************************************************
-        Construction and Destruction
-    *************************************************************************/
-    GUISheetFactory(void) : WindowFactory(GUISheet::WidgetTypeName) { }
-    ~GUISheetFactory(void){}
-
-
-    /*!
-    \brief
-        Create a new Window object of whatever type this WindowFactory produces.
-
-    \param name
-        A unique name that is to be assigned to the newly created Window object
-
-    \return
-        Pointer to the new Window object.
-    */
-    Window* createWindow(const String& name)
-    {
-        return new GUISheet(d_type, name);
-    }
-
-
-    /*!
-    \brief
-        Destroys the given Window object.
-
-    \param window
-        Pointer to the Window object to be destroyed.
-
-    \return
-        Nothing.
-    */
-    virtual void    destroyWindow(Window* window)    { if (window->getType() == d_type) delete window; }
-};
-
 /*!
 \brief
     typedef for DefaultWindow, which is the new name for GUISheet.
