@@ -1,28 +1,32 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIListHeader.h
 	created:	13/4/2004
 	author:		Paul D Turner
 	
 	purpose:	Interface to base class for ListHeader widget
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #ifndef _CEGUIListHeader_h_
 #define _CEGUIListHeader_h_
 
@@ -54,6 +58,46 @@ public:
 	uint d_newIdx;		//!< The new column index of the segment that has moved.
 };
 
+/*!
+\brief
+    Base class for the multi column list header window renderer.
+*/
+class CEGUIEXPORT ListHeaderWindowRenderer : public WindowRenderer
+{
+public:
+    /*!
+    \brief
+        Constructor
+    */
+    ListHeaderWindowRenderer(const String& name);
+
+    /*!
+    \brief
+        Create and return a pointer to a new ListHeaderSegment based object.
+
+    \param name
+        String object holding the name that should be given to the new Window.
+
+    \return
+        Pointer to an ListHeaderSegment based object of whatever type is appropriate for
+        this ListHeader.
+    */
+    virtual ListHeaderSegment*  createNewSegment(const String& name) const  = 0;
+
+    /*!
+    \brief
+        Cleanup and destroy the given ListHeaderSegment that was created via the
+        createNewSegment method.
+
+    \param segment
+        Pointer to a ListHeaderSegment based object to be destroyed.
+
+    \return
+        Nothing.
+    */
+    virtual void    destroyListSegment(ListHeaderSegment* segment) const = 0;
+};
+
 
 /*!
 \brief
@@ -63,6 +107,7 @@ class CEGUIEXPORT ListHeader : public Window
 {
 public:
 	static const String EventNamespace;				//!< Namespace for global events
+    static const String WidgetTypeName;             //!< Window factory name
 
 
 	/*************************************************************************
@@ -86,6 +131,11 @@ public:
 	static const float	ScrollSpeed;				//!< Speed to scroll at when dragging outside header.
 	static const float	MinimumSegmentPixelWidth;	//!< Miniumum width of a segment in pixels.
 
+    /*************************************************************************
+        Child Widget name suffix constants
+    *************************************************************************/
+    static const char SegmentNameSuffix[];          //!< Widget name suffix for header segments.
+
 
 	/*************************************************************************
 		Accessor Methods
@@ -245,17 +295,18 @@ public:
 
 	/*!
 	\brief
-		Return the pixel width of the specified column.
+		Return the width of the specified column.
 
 	\param column
-		Zero based column index of the segment whos pixel width is to be returned.
+		Zero based column index of the segment whose width is to be returned.
 
 	\return
-		Pixel width of the ListHeaderSegment at the zero based column index specified by \a column.
+		UDim describing the width of the ListHeaderSegment at the zero based
+        column index specified by \a column.
 
 	\exception InvalidRequestException	thrown if \a column is out of range.
 	*/
-	float	getColumnPixelWidth(uint column) const;
+	UDim getColumnWidth(uint column) const;
 
 
 	/*!
@@ -424,12 +475,12 @@ public:
 		Client specified ID code to be assigned to the new segment.
 
 	\param width
-		Initial width of the new segment using the relative metrics system
+		UDim describing the initial width of the new segment.
 
 	\return
 		Nothing.
 	*/
-	void	addColumn(const String& text, uint id, float width);
+	void	addColumn(const String& text, uint id, const UDim& width);
 
 
 	/*!
@@ -442,8 +493,8 @@ public:
 	\param id
 		Client specified ID code to be assigned to the new segment.
 
-	\param width
-		Initial width of the new segment using the relative metrics system
+    \param width
+        UDim describing the initial width of the new segment.
 
 	\param position
 		Zero based column index indicating the desired position for the new column.  If this is greater than
@@ -452,7 +503,7 @@ public:
 	\return
 		Nothing.
 	*/
-	void	insertColumn(const String& text, uint id, float width, uint position);
+	void	insertColumn(const String& text, uint id, const UDim& width, uint position);
 
 
 	/*!
@@ -465,8 +516,8 @@ public:
 	\param id
 		Client specified ID code to be assigned to the new segment.
 
-	\param width
-		Initial width of the new segment using the relative metrics system
+    \param width
+        UDim describing the initial width of the new segment.
 
 	\param position
 		ListHeaderSegment object indicating the insert position for the new segment.  The new segment will be
@@ -477,7 +528,7 @@ public:
 
 	\exception InvalidRequestException	thrown if ListHeaderSegment \a position is not attached to the ListHeader.
 	*/
-	void	insertColumn(const String& text, uint id, float width, const ListHeaderSegment& position);
+	void	insertColumn(const String& text, uint id, const UDim& width, const ListHeaderSegment& position);
 
 
 	/*!
@@ -606,13 +657,13 @@ public:
 
 	/*!
 	\brief
-		Set the pixel width of the specified column.
+		Set the width of the specified column.
 
 	\param column
-		Zero based column index of the segment whos pixel width is to be set.
+		Zero based column index of the segment whose width is to be set.
 
 	\param width
-		float value specifying the new pixel width to set for the ListHeaderSegment at the zero based column
+		UDim value specifying the new width to set for the ListHeaderSegment at the zero based column
 		index specified by \a column.
 
 	\return
@@ -620,7 +671,7 @@ public:
 
 	\exception InvalidRequestException	thrown if \a column is out of range.
 	*/
-	void	setColumnPixelWidth(uint column, float width);
+	void	setColumnWidth(uint column, const UDim& width);
 
 
 	/*************************************************************************
@@ -655,7 +706,7 @@ protected:
 		Pointer to an ListHeaderSegment based object of whatever type is appropriate for
 		this ListHeader.
 	*/
-	virtual ListHeaderSegment*	createNewSegment(const String& name) const	= 0;
+	//virtual ListHeaderSegment*	createNewSegment_impl(const String& name) const	= 0;
 
 
 	/*!
@@ -669,7 +720,7 @@ protected:
 	\return
 		Nothing.
 	*/
-	virtual void	destroyListSegment(ListHeaderSegment* segment) const = 0;
+	//virtual void	destroyListSegment_impl(ListHeaderSegment* segment) const = 0;
 
 
 	/*************************************************************************
@@ -679,7 +730,7 @@ protected:
 	\brief
 		Create initialise and return a ListHeaderSegment object, with all events subscribed and ready to use.
 	*/
-	ListHeaderSegment*	createInitialisedSegment(const String& text, uint id, float width);
+	ListHeaderSegment*	createInitialisedSegment(const String& text, uint id, const UDim& width);
 
 
 	/*!
@@ -691,14 +742,7 @@ protected:
 
 	/*!
 	\brief
-		Add ListHeader specific events
-	*/
-	void	addListHeaderEvents(void);
-
-
-	/*!
-	\brief
-		Return whether this window was inherited from the given class name at some point in the inheritance heirarchy.
+		Return whether this window was inherited from the given class name at some point in the inheritance hierarchy.
 
 	\param class_name
 		The class name that is to be checked.
@@ -708,11 +752,44 @@ protected:
 	*/
 	virtual bool	testClassName_impl(const String& class_name) const
 	{
-		if (class_name==(const utf8*)"ListHeader")	return true;
+		if (class_name=="ListHeader")	return true;
 		return Window::testClassName_impl(class_name);
 	}
 
 
+    /*!
+    \brief
+        Create and return a pointer to a new ListHeaderSegment based object.
+
+    \param name
+        String object holding the name that should be given to the new Window.
+
+    \return
+        Pointer to an ListHeaderSegment based object of whatever type is appropriate for
+        this ListHeader.
+    */
+    ListHeaderSegment*  createNewSegment(const String& name) const;
+
+
+    /*!
+    \brief
+        Cleanup and destroy the given ListHeaderSegment that was created via the
+        createNewSegment method.
+
+    \param segment
+        Pointer to a ListHeaderSegment based object to be destroyed.
+
+    \return
+        Nothing.
+    */
+    void    destroyListSegment(ListHeaderSegment* segment) const;
+
+    // validate window renderer
+    virtual bool validateWindowRenderer(const String& name) const
+    {
+        return (name == "ListHeader");
+    }
+
 	/*************************************************************************
 		New List header event handlers
 	*************************************************************************/
@@ -799,7 +876,6 @@ protected:
 	*/
 	virtual	void	onSegmentOffsetChanged(WindowEventArgs& e);
 
-
 	/*************************************************************************
 		handlers for events we subscribe to from segments
 	*************************************************************************/
@@ -841,6 +917,7 @@ private:
 	void	addHeaderProperties(void);
 };
 
+
 } // End of  CEGUI namespace section
 
 
