@@ -2,7 +2,7 @@
 	filename: 	CEGUIListbox.h
 	created:	13/4/2004
 	author:		Paul D Turner
-	
+
 	purpose:	Interface to base class for Listbox widget
 *************************************************************************/
 /***************************************************************************
@@ -110,7 +110,7 @@ public:
 	*/
 	size_t	getItemCount(void) const		{return d_listItems.size();}
 
-	
+
 	/*!
 	\brief
 		Return the number of selected items in the list box.
@@ -307,22 +307,26 @@ public:
 
 	/*!
 	\brief
-		Insert an item into the list box after a specified item already in the list.
+		Insert an item into the list box before a specified item already in the
+        list.
 
-		Note that if the list is sorted, the item may not end up in the requested position.
+		Note that if the list is sorted, the item may not end up in the
+        requested position.
 
 	\param item
-		Pointer to the ListboxItem to be inserted.  Note that it is the passed object that is added to the
-		list, a copy is not made.  If this parameter is NULL, nothing happens.
+		Pointer to the ListboxItem to be inserted.  Note that it is the passed
+        object that is added to the list, a copy is not made.  If this parameter
+        is NULL, nothing happens.
 
 	\param position
-		Pointer to a ListboxItem that \a item is to be inserted after.  If this parameter is NULL, the item is
-		inserted at the start of the list.
+		Pointer to a ListboxItem that \a item is to be inserted before.  If this
+        parameter is NULL, the item is inserted at the start of the list.
 
 	\return
 		Nothing.
-	
-	\exception InvalidRequestException	thrown if no ListboxItem \a position is attached to this list box.
+
+	\exception InvalidRequestException	thrown if no ListboxItem \a position is
+        attached to this list box.
 	*/
 	void	insertItem(ListboxItem* item, const ListboxItem* position);
 
@@ -363,7 +367,7 @@ public:
 	*/
 	void	setSortingEnabled(bool setting);
 
-	
+
 	/*!
 	\brief
 		Set whether the list should allow multiple selections or just a single selection
@@ -422,7 +426,7 @@ public:
 
 	\return
 		Nothing.
-	
+
 	\exception	InvalidRequestException	thrown if \a item is not attached to this list box.
 	*/
 	void	setItemSelectState(ListboxItem* item, bool state);
@@ -444,7 +448,7 @@ public:
 
 	\return
 		Nothing.
-	
+
 	\exception	InvalidRequestException	thrown if \a item_index is out of range for the list box
 	*/
 	void	setItemSelectState(size_t item_index, bool state);
@@ -661,6 +665,11 @@ protected:
         return (name == "Listbox");
     }
 
+    /*!
+    \brief
+        Causes the internal list to be (re)sorted.
+    */
+    void resortList();
 
 	/*************************************************************************
 		New event handlers
