@@ -1,28 +1,32 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIListboxTextItem.h
 	created:	12/6/2004
 	author:		Paul D Turner
 	
 	purpose:	Interface for list box text items
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #ifndef _CEGUIListboxTextItem_h_
 #define _CEGUIListboxTextItem_h_
 #include "elements/CEGUIListboxItem.h"
@@ -51,7 +55,7 @@ public:
 	\brief
 		base class constructor
 	*/
-	ListboxTextItem(const String& text, uint item_id = 0, void* item_data = NULL, bool disabled = false, bool auto_delete = true);
+	ListboxTextItem(const String& text, uint item_id = 0, void* item_data = 0, bool disabled = false, bool auto_delete = true);
 
 
 	/*!
@@ -74,7 +78,7 @@ public:
 	\return
 		Font to be used for rendering this item
 	*/
-	const Font*	getFont(void) const;
+	Font*	getFont(void) const;
 
 
 	/*!
@@ -100,7 +104,7 @@ public:
 	\return
 		Nothing
 	*/
-	void	setFont(const Font* font)		{d_font = font;}
+	void	setFont(Font* font)		{d_font = font;}
 
 
 	/*!
@@ -175,8 +179,8 @@ protected:
 	/*************************************************************************
 		Implementation Data
 	*************************************************************************/
-	ColourRect		d_textCols;			//!< Colours used for rendering the text.
-	const Font*		d_font;				//!< Font used for rendering text.
+	ColourRect	d_textCols;			//!< Colours used for rendering the text.
+	Font*		d_font;				//!< Font used for rendering text.
 };
 
 } // End of  CEGUI namespace section
