@@ -1,26 +1,30 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIScrollablePane.h
 	created:	1/3/2005
 	author:		Paul D Turner
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #ifndef _CEGUIScrollablePane_h_
 #define _CEGUIScrollablePane_h_
 
@@ -36,6 +40,30 @@
 // Start of CEGUI namespace section
 namespace CEGUI
 {
+    /*!
+    \brief
+        Base class for ScrollablePane window renderer objects.
+    */
+    class CEGUIEXPORT ScrollablePaneWindowRenderer : public WindowRenderer
+    {
+    public:
+        /*!
+        \brief
+            Constructor
+        */
+        ScrollablePaneWindowRenderer(const String& name);
+
+        /*!
+        \brief
+            Return a Rect that described the pane's viewable area, relative
+            to this Window, in pixels.
+
+        \return
+            Rect object describing the ScrollablePane's viewable area.
+        */
+        virtual Rect getViewableArea(void) const = 0;
+    };
+
     /*!
     \brief
         Base class for the ScrollablePane widget.
@@ -50,6 +78,7 @@ namespace CEGUI
         /*************************************************************************
             Constants
         *************************************************************************/
+        static const String WidgetTypeName;                 //!< Window factory name
         static const String EventNamespace;                 //!< Namespace for global events
         static const String EventContentPaneChanged;        //!< Event fired when an area on the content pane has been updated.
         static const String EventVertScrollbarModeChanged;	//!< Event triggered when the vertical scroll bar 'force' setting changes.
@@ -57,6 +86,13 @@ namespace CEGUI
         static const String EventAutoSizeSettingChanged;    //!< Event fired when the auto size setting changes.
         static const String EventContentPaneScrolled;       //!< Event fired when the pane gets scrolled.
 
+        /*************************************************************************
+            Child Widget name suffix constants
+        *************************************************************************/
+        static const String VertScrollbarNameSuffix;        //!< Widget name suffix for the vertical scrollbar component.
+        static const String HorzScrollbarNameSuffix;        //!< Widget name suffix for the horizontal scrollbar component.
+        static const String ScrolledContainerNameSuffix;    //!< Widget name suffix for the scrolled container component.
+
         /*************************************************************************
             Construction / Destruction
         *************************************************************************/
@@ -330,39 +366,6 @@ namespace CEGUI
         */
         void setVerticalScrollPosition(float position);
 
-        /*************************************************************************
-            Overridden from Window
-        *************************************************************************/
-        void initialise(void);
-
-    protected:
-        /*************************************************************************
-        	Abstract interface
-        *************************************************************************/
-        /*!
-        \brief
-            Create a Scrollbar based widget to be used as the horizontal scrollbar.
-
-        \param name
-            String object holding the name that must be used when creating the widget.
-
-        \return
-            Scrollbar based object.
-        */
-        virtual Scrollbar* createHorizontalScrollbar(const String& name) const = 0;
-
-        /*!
-        \brief
-            Create a Scrollbar based widget to be used as the vertical scrollbar.
-
-        \param name
-            String object holding the name that must be used when creating the widget.
-
-        \return
-            Scrollbar based object.
-        */
-        virtual Scrollbar* createVerticalScrollbar(const String& name) const = 0;
-
         /*!
         \brief
             Return a Rect that described the pane's viewable area, relative
@@ -371,17 +374,57 @@ namespace CEGUI
         \return
             Rect object describing the ScrollablePane's viewable area.
         */
-        virtual Rect getViewableArea(void) const = 0;
+        Rect getViewableArea(void) const;
+
+        /*!
+        \brief
+            Return a pointer to the vertical scrollbar component widget for this
+            ScrollablePane.
+
+        \return
+            Pointer to a Scrollbar object.
+
+        \exception UnknownObjectException
+            Thrown if the vertical Scrollbar component does not exist.
+        */
+        Scrollbar* getVertScrollbar() const;
+
+        /*!
+        \brief
+            Return a pointer to the horizontal scrollbar component widget for
+            this ScrollablePane.
+
+        \return
+            Pointer to a Scrollbar object.
+
+        \exception UnknownObjectException
+            Thrown if the horizontal Scrollbar component does not exist.
+        */
+        Scrollbar* getHorzScrollbar() const;
+
+        /*************************************************************************
+            Overridden from Window
+        *************************************************************************/
+        void initialiseComponents(void);
+        void destroy(void);
+
+    protected:
+        /*************************************************************************
+        	Abstract interface
+        *************************************************************************/
+        /*!
+        \brief
+            Return a Rect that described the pane's viewable area, relative
+            to this Window, in pixels.
+
+        \return
+            Rect object describing the ScrollablePane's viewable area.
+        */
+        //virtual Rect getViewableArea_impl(void) const = 0;
 
         /*************************************************************************
         	Implementation Methods
         *************************************************************************/
-        /*!
-        \brief
-            Add ScrollablePane specific events
-        */
-        void addScrollablePaneEvents(void);
-
         /*!
 	    \brief
 		    display required integrated scroll bars according to current size of
@@ -419,7 +462,7 @@ namespace CEGUI
 
 		/*!
 		\brief
-			Return whether this window was inherited from the given class name at some point in the inheritance heirarchy.
+			Return whether this window was inherited from the given class name at some point in the inheritance hierarchy.
 
 		\param class_name
 			The class name that is to be checked.
@@ -429,10 +472,28 @@ namespace CEGUI
 		*/
 		virtual bool	testClassName_impl(const String& class_name) const
 		{
-			if (class_name==(const utf8*)"ScrollablePane")	return true;
+			if (class_name=="ScrollablePane")	return true;
 			return Window::testClassName_impl(class_name);
 		}
 
+        /*!
+        \brief
+            Return a pointer to the ScrolledContainer component widget for this
+            ScrollablePane.
+
+        \return
+            Pointer to a ScrolledContainer object.
+
+        \exception UnknownObjectException
+            Thrown if the scrolled container component does not exist.
+        */
+        ScrolledContainer* getScrolledContainer() const;
+
+        // validate window renderer
+        virtual bool validateWindowRenderer(const String& name) const
+        {
+            return (name == "ScrollablePane");
+        }
 
         /*************************************************************************
         	Event triggers
@@ -544,11 +605,8 @@ namespace CEGUI
         float   d_vertOverlap;          //!< vertical scroll overlap fraction.
         float   d_horzStep;             //!< horizontal scroll step fraction.
         float   d_horzOverlap;          //!< horizontal scroll overlap fraction.
-
-        // component widgets
-        Scrollbar*  d_vertScrollbar;        //!< Scrollbar widget used for vertical scrolling.
-        Scrollbar*  d_horzScrollbar;        //!< Scrollbar widget used for horizontal scrolling.
-        ScrolledContainer*  d_container;    //!< ScrolledContainer widget holding the attached widgets.
+        Event::Connection d_contentChangedConn;  //!< Event connection to content pane
+        Event::Connection d_autoSizeChangedConn; //!< Event connection to content pane
 
     private:
 	    /*************************************************************************
@@ -571,6 +629,7 @@ namespace CEGUI
 	    void addScrollablePaneProperties(void);
     };
 
+
 } // End of  CEGUI namespace section
 
 
