@@ -1,32 +1,37 @@
-/************************************************************************
+/***********************************************************************
     filename:   CEGUIFalDimensions.h
     created:    Mon Jun 13 2005
     author:     Paul D Turner <paul@cegui.org.uk>
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
- 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
- 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
- 
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #ifndef _CEGUIFalDimensions_h_
 #define _CEGUIFalDimensions_h_
 
 #include "falagard/CEGUIFalEnums.h"
 #include "CEGUIString.h"
 #include "CEGUIUDim.h"
+#include "CEGUIXMLSerializer.h"
 
 // Start of CEGUI namespace section
 namespace CEGUI
@@ -137,13 +142,13 @@ namespace CEGUI
         \brief
             Writes an xml representation of this BaseDim to \a out_stream.
 
-        \param out_stream
+        \param xml_stream
             Stream where xml data should be output.
 
         \return
             Nothing.
         */
-        void writeXMLToStream(OutStream& out_stream) const;
+        void writeXMLToStream(XMLSerializer& xml_stream) const;
 
     protected:
         /*!
@@ -170,19 +175,15 @@ namespace CEGUI
 
         /*!
         \brief
-            Implementataion method to output real xml element name to an OutStream.
-            This method should not write the element opening '<' character, nor close the element, it
-            must write just the element name itself.
+            Implementataion method to output real xml element name.
         */
-        virtual void writeXMLElementName_impl(OutStream& out_stream) const = 0;
+        virtual void writeXMLElementName_impl(XMLSerializer& xml_stream) const = 0;
 
         /*!
         \brief
-            Implementataion method to output xml element attributes to an OutStream.
-            This method should not write the element opening '<' character, nor close the element, it
-            must write just the element attributes.
+            Implementataion method to create the element attributes
         */
-        virtual void writeXMLElementAttributes_impl(OutStream& out_stream) const = 0;
+        virtual void writeXMLElementAttributes_impl(XMLSerializer& xml_stream) const = 0;
 
     private:
         DimensionOperator   d_operator;
@@ -216,8 +217,8 @@ namespace CEGUI
         // Implementation of the base class interface
         float getValue_impl(const Window& wnd) const;
         float getValue_impl(const Window& wnd, const Rect& container) const;
-        void writeXMLElementName_impl(OutStream& out_stream) const;
-        void writeXMLElementAttributes_impl(OutStream& out_stream) const;
+        void writeXMLElementName_impl(XMLSerializer& xml_stream) const;
+        void writeXMLElementAttributes_impl(XMLSerializer& xml_stream) const;
 
         BaseDim* clone_impl() const;
 
@@ -281,8 +282,8 @@ namespace CEGUI
         // Implementation of the base class interface
         float getValue_impl(const Window& wnd) const;
         float getValue_impl(const Window& wnd, const Rect& container) const;
-        void writeXMLElementName_impl(OutStream& out_stream) const;
-        void writeXMLElementAttributes_impl(OutStream& out_stream) const;
+        void writeXMLElementName_impl(XMLSerializer& xml_stream) const;
+        void writeXMLElementAttributes_impl(XMLSerializer& xml_stream) const;
         BaseDim* clone_impl() const;
 
     private:
@@ -346,8 +347,8 @@ namespace CEGUI
         // Implementation of the base class interface
         float getValue_impl(const Window& wnd) const;
         float getValue_impl(const Window& wnd, const Rect& container) const;
-        void writeXMLElementName_impl(OutStream& out_stream) const;
-        void writeXMLElementAttributes_impl(OutStream& out_stream) const;
+        void writeXMLElementName_impl(XMLSerializer& xml_stream) const;
+        void writeXMLElementAttributes_impl(XMLSerializer& xml_stream) const;
         BaseDim* clone_impl() const;
 
     private:
@@ -381,8 +382,8 @@ namespace CEGUI
         // Implementation of the base class interface
         float getValue_impl(const Window& wnd) const;
         float getValue_impl(const Window& wnd, const Rect& container) const;
-        void writeXMLElementName_impl(OutStream& out_stream) const;
-        void writeXMLElementAttributes_impl(OutStream& out_stream) const;
+        void writeXMLElementName_impl(XMLSerializer& xml_stream) const;
+        void writeXMLElementAttributes_impl(XMLSerializer& xml_stream) const;
         BaseDim* clone_impl() const;
 
     private:
@@ -425,8 +426,8 @@ namespace CEGUI
         // Implementation of the base class interface
         float getValue_impl(const Window& wnd) const;
         float getValue_impl(const Window& wnd, const Rect& container) const;
-        void writeXMLElementName_impl(OutStream& out_stream) const;
-        void writeXMLElementAttributes_impl(OutStream& out_stream) const;
+        void writeXMLElementName_impl(XMLSerializer& xml_stream) const;
+        void writeXMLElementAttributes_impl(XMLSerializer& xml_stream) const;
         BaseDim* clone_impl() const;
 
     private:
@@ -439,7 +440,8 @@ namespace CEGUI
 
     /*!
     \brief
-        Dimension type that represents the value of a Window property.  Implements BaseDim interface.
+        Dimension type that represents the value of a Window property.
+        Implements BaseDim interface.
     */
     class CEGUIEXPORT PropertyDim : public BaseDim
     {
@@ -449,25 +451,40 @@ namespace CEGUI
             Constructor.
 
         \param name
-            String holding the name suffix of the window on which the property is to be accessed.
+            String holding the name suffix of the window on which the property
+            is to be accessed.
 
         \param property
-            String object holding the name of the property this PropertyDim represents the value of.
-            The property named should represent a simple float value.
+            String object holding the name of the property this PropertyDim
+            represents the value of.  The property named should represent either
+            a UDim value or a simple float value - dependning upon what \a type
+            is specified as.
+
+        \param type
+            DimensionType value indicating what dimension named property
+            represents.  The possible DimensionType values are as follows:
+            - DT_INVALID the property should represent a simple float value.
+            - DT_WIDTH the property should represent a UDim value where the
+            scale is relative to the targetted Window's width.
+            - DT_HEIGHT the property should represent a UDim value where the
+            scale is relative to the targetted Window's height.
+            - All other values will cause an InvalidRequestException exception
+            to be thrown.
         */
-        PropertyDim(const String& name, const String& property);
+        PropertyDim(const String& name, const String& property, DimensionType type);
 
     protected:
         // Implementation of the base class interface
         float getValue_impl(const Window& wnd) const;
         float getValue_impl(const Window& wnd, const Rect& container) const;
-        void writeXMLElementName_impl(OutStream& out_stream) const;
-        void writeXMLElementAttributes_impl(OutStream& out_stream) const;
+        void writeXMLElementName_impl(XMLSerializer& xml_stream) const;
+        void writeXMLElementAttributes_impl(XMLSerializer& xml_stream) const;
         BaseDim* clone_impl() const;
 
     private:
         String d_property;      //!< Propery that this object represents.
-        String  d_childSuffix;  //!< String to hold the name suffix of the child to access the property form.
+        String d_childSuffix;   //!< String to hold the name suffix of the child to access the property form.
+        DimensionType d_type;   //!< String to hold the type of dimension
     };
 
     /*!
@@ -563,13 +580,13 @@ namespace CEGUI
         \brief
             Writes an xml representation of this Dimension to \a out_stream.
 
-        \param out_stream
+        \param xml_stream
             Stream where xml data should be output.
 
         \return
             Nothing.
         */
-        void writeXMLToStream(OutStream& out_stream) const;
+        void writeXMLToStream(XMLSerializer& xml_stream) const;
 
     private:
         BaseDim*        d_value;    //!< Pointer to the value for this Dimension.
@@ -622,13 +639,14 @@ namespace CEGUI
         \brief
             Writes an xml representation of this ComponentArea to \a out_stream.
 
-        \param out_stream
+        \param xml_stream
             Stream where xml data should be output.
 
+
         \return
             Nothing.
         */
-        void writeXMLToStream(OutStream& out_stream) const;
+        void writeXMLToStream(XMLSerializer& xml_stream) const;
 
         /*!
         \brief
