@@ -8,9 +8,12 @@ package.files =
 {
     matchfiles(pkgdir.."*.cpp"),
     matchfiles(pkgdir.."*.h"),
+    matchfiles(pkgdir.."GLEW/src/*.c"),
+    matchfiles(pkgdir.."GLEW/GL/*.h"),
 }
 
 include(pkgdir)
+include(pkgdir.."GLEW")
 include(rootdir)
 
 if windows then
@@ -22,3 +25,4 @@ end
 dependency("CEGUIBase")
 
 define("OPENGL_GUIRENDERER_EXPORTS")
+define("GLEW_STATIC")
