@@ -12,7 +12,8 @@ package.files =
 
 include(pkgdir)
 
-library("libexpatMT", "_d")
+library("expat", "_d")
+library_static("expat","","_d")
 
 dependency("CEGUIBase")
 
