@@ -1,32 +1,37 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIEventSet.cpp
 	created:	21/2/2004
 	author:		Paul D Turner
 	
 	purpose:	Implements the EventSet class
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #include "CEGUIEventSet.h"
 #include "CEGUIExceptions.h"
 #include "CEGUIGlobalEventSet.h"
 #include "CEGUIScriptModule.h"
+#include "CEGUISystem.h"
 
 // Start of CEGUI namespace section
 namespace CEGUI
@@ -110,7 +115,13 @@ bool EventSet::isEventPresent(const String& name)
 *************************************************************************/
 Event::Connection EventSet::subscribeScriptedEvent(const String& name, const String& subscriber_name)
 {
-	return subscribeEvent(name, Event::Subscriber(ScriptFunctor(subscriber_name)));
+	//return subscribeEvent(name, Event::Subscriber(ScriptFunctor(subscriber_name)));
+	ScriptModule* sm = System::getSingletonPtr()->getScriptingModule();
+	if (!sm)
+	{
+	   throw InvalidRequestException("[EventSet::subscribeScriptedEvent] No scripting module is available");
+	}
+	return sm->subscribeEvent(this, name, subscriber_name);
 }
 
 
@@ -119,7 +130,13 @@ Event::Connection EventSet::subscribeScriptedEvent(const String& name, const Str
 *************************************************************************/
 Event::Connection EventSet::subscribeScriptedEvent(const String& name, Event::Group group, const String& subscriber_name)
 {
-	return subscribeEvent(name, group, Event::Subscriber(ScriptFunctor(subscriber_name)));
+        //return subscribeEvent(name, group, Event::Subscriber(ScriptFunctor(subscriber_name)));
+        ScriptModule* sm = System::getSingletonPtr()->getScriptingModule();
+	if (!sm)
+	{
+	   throw InvalidRequestException("[EventSet::subscribeScriptedEvent] No scripting module is available");
+	}
+	return sm->subscribeEvent(this, name, group, subscriber_name);
 }
 
 
@@ -128,14 +145,8 @@ Event::Connection EventSet::subscribeScriptedEvent(const String& name, Event::Gr
 *************************************************************************/
 Event::Connection EventSet::subscribeEvent(const String& name, Event::Subscriber subscriber)
 {
-	EventMap::iterator pos = d_events.find(name);
-
-	if (pos == d_events.end())
-	{
-		throw UnknownObjectException("No event named '" + name + "' is defined for this EventSet");	
-	}
-
-	return pos->second->subscribe(subscriber);
+    // do subscription & return connection
+    return getEventObject(name, true)->subscribe(subscriber);
 }
 
 
@@ -144,14 +155,8 @@ Event::Connection EventSet::subscribeEvent(const String& name, Event::Subscriber
 *************************************************************************/
 Event::Connection EventSet::subscribeEvent(const String& name, Event::Group group, Event::Subscriber subscriber)
 {
-	EventMap::iterator pos = d_events.find(name);
-
-	if (pos == d_events.end())
-	{
-		throw UnknownObjectException("No event named '" + name + "' is defined for this EventSet");	
-	}
-
-	return pos->second->subscribe(group, subscriber);
+    // do subscription with group & return connection
+    return getEventObject(name, true)->subscribe(group, subscriber);
 }
 
 /*************************************************************************
@@ -161,20 +166,8 @@ void EventSet::fireEvent(const String& name, EventArgs& args, const String& even
 {
     // handle global events
     GlobalEventSet::getSingleton().fireEvent(name, args, eventNamespace);
-
-    EventMap::iterator pos = d_events.find(name);
-
-	if (pos == d_events.end())
-	{
-		throw UnknownObjectException("No event named '" + name + "' is defined for this EventSet");	
-	}
-
-	// fire the event
-	if (!d_muted)
-	{
-		(*pos->second)(args);
-	}
-
+    // handle local event
+    fireEvent_impl(name, args);
 }
 
 
@@ -196,13 +189,53 @@ void EventSet::setMutedState(bool setting)
 }
 
 
+/*************************************************************************
+    Return the named Event object, optionally adding it to the set
+    if needed
+*************************************************************************/
+Event* EventSet::getEventObject(const String& name, bool autoAdd)
+{
+    EventMap::iterator pos = d_events.find(name);
+
+    // if event did not exist, add it and then find it.
+    if (pos == d_events.end())
+    {
+        if (autoAdd)
+        {
+            addEvent(name);
+            return d_events.find(name)->second;
+        }
+        else
+        {
+            return 0;
+        }
+    }
+
+    return pos->second;
+}
+
+
+/*************************************************************************
+
+*************************************************************************/
+void EventSet::fireEvent_impl(const String& name, EventArgs& args)
+{
+    // find event object
+    Event* ev = getEventObject(name);
+
+    // fire the event if present and set is not muted
+    if ((ev != 0) && !d_muted)
+        (*ev)(args);
+}
+
+
 /*************************************************************************
 	Return a EventSet::EventIterator object to iterate over the available
 	events.
 *************************************************************************/
-EventSet::EventIterator EventSet::getIterator(void) const
+EventSet::Iterator EventSet::getIterator(void) const
 {
-	return EventIterator(d_events.begin(), d_events.end());
+	return Iterator(d_events.begin(), d_events.end());
 }
 
 
