@@ -1,28 +1,32 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIImage.cpp
 	created:	13/3/2004
 	author:		Paul D Turner
 	
 	purpose:	Implementation of Image class members
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #include "CEGUIImage.h"
 #include "CEGUIExceptions.h"
 #include "CEGUITexture.h"
@@ -45,9 +49,9 @@ Image::Image(const Imageset* owner, const String& name, const Rect& area, const
 	d_offset(render_offset),
 	d_name(name)
 {
-	if (d_owner == NULL)
+	if (!d_owner)
 	{
-		throw NullObjectException((utf8*)"Image::Image - Imageset pointer passed to Image constructor must not be null.");
+		throw NullObjectException("Image::Image - Imageset pointer passed to Image constructor must be valid.");
 	}
 
 	// setup initial image scaling
@@ -143,21 +147,22 @@ const Rect& Image::getSourceTextureArea(void) const
 /*************************************************************************
     Output XML <Image ... > element for this image
 *************************************************************************/
-void Image::writeXMLToStream(OutStream& out_stream) const
+void Image::writeXMLToStream(XMLSerializer& xml_stream) const
 {
-    out_stream << "<Image Name=\"" << d_name.c_str() << "\" ";
-    out_stream << "XPos=\"" << PropertyHelper::uintToString(static_cast<uint>(d_area.d_left)) << "\" ";
-    out_stream << "YPos=\"" << PropertyHelper::uintToString(static_cast<uint>(d_area.d_top)) << "\" ";
-    out_stream << "Width=\"" << PropertyHelper::uintToString(static_cast<uint>(d_area.getWidth())) << "\" ";
-    out_stream << "Height=\"" << PropertyHelper::uintToString(static_cast<uint>(d_area.getHeight())) << "\" ";
+    xml_stream.openTag("Image")
+        .attribute("Name", d_name)
+        .attribute("XPos", PropertyHelper::uintToString(static_cast<uint>(d_area.d_left)))
+        .attribute("YPos", PropertyHelper::uintToString(static_cast<uint>(d_area.d_top)))
+        .attribute("Width", PropertyHelper::uintToString(static_cast<uint>(d_area.getWidth())))
+        .attribute("Height", PropertyHelper::uintToString(static_cast<uint>(d_area.getHeight())));
 
     if (d_offset.d_x != 0.0f)
-        out_stream << "XOffset=\"" << PropertyHelper::intToString(static_cast<int>(d_offset.d_x)) << "\" ";
+        xml_stream.attribute("XOffset", PropertyHelper::intToString(static_cast<int>(d_offset.d_x)));
 
     if (d_offset.d_y != 0.0f)
-        out_stream << "YOffset=\"" << PropertyHelper::intToString(static_cast<int>(d_offset.d_x)) << "\" ";
+        xml_stream.attribute("YOffset", PropertyHelper::intToString(static_cast<int>(d_offset.d_x)));
 
-    out_stream << "/>" << std::endl;
+    xml_stream.closeTag();
 }
 
 
