@@ -1,9 +1,9 @@
 /***********************************************************************
-	filename: 	CEGUIWindowManager.cpp
-	created:	21/2/2004
-	author:		Paul D Turner
-	
-	purpose:	Implements the WindowManager class
+    filename:   CEGUIWindowManager.cpp
+    created:    21/2/2004
+    author:     Paul D Turner
+
+    purpose:    Implements the WindowManager class
 *************************************************************************/
 /***************************************************************************
  *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
@@ -41,18 +41,18 @@
 namespace CEGUI
 {
 /*************************************************************************
-	Static Data Definitions
+    Static Data Definitions
 *************************************************************************/
 // singleton instance pointer
-template<> WindowManager* Singleton<WindowManager>::ms_Singleton	= 0;
+template<> WindowManager* Singleton<WindowManager>::ms_Singleton    = 0;
 // default resource group
 String WindowManager::d_defaultResourceGroup;
 
 /*************************************************************************
-	Definition of constant data for WindowManager
+    Definition of constant data for WindowManager
 *************************************************************************/
 // Declared in WindowManager
-const char	WindowManager::GUILayoutSchemaName[]	= "GUILayout.xsd";
+const char  WindowManager::GUILayoutSchemaName[]    = "GUILayout.xsd";
 const String WindowManager::GeneratedWindowNameBase("__cewin_uid_");
 
 
@@ -60,29 +60,41 @@ const String WindowManager::GeneratedWindowNameBase("__cewin_uid_");
     Constructor
 *************************************************************************/
 WindowManager::WindowManager(void) :
-    d_uid_counter(0)
+    d_uid_counter(0),
+    d_lockCount(0)
 {
-    Logger::getSingleton().logEvent("CEGUI::WindowManager singleton created");
+    char addr_buff[32];
+    sprintf(addr_buff, "(%p)", static_cast<void*>(this));
+    Logger::getSingleton().logEvent(
+        "CEGUI::WindowManager singleton created " + String(addr_buff));
 }
 
 
 /*************************************************************************
-	Destructor
+    Destructor
 *************************************************************************/
 WindowManager::~WindowManager(void)
 {
-	destroyAllWindows();
+    destroyAllWindows();
     cleanDeadPool();
 
-	Logger::getSingleton().logEvent("CEGUI::WindowManager singleton destroyed");
+    char addr_buff[32];
+    sprintf(addr_buff, "(%p)", static_cast<void*>(this));
+    Logger::getSingleton().logEvent(
+        "CEGUI::WindowManager singleton destroyed " + String(addr_buff));
 }
 
 
 /*************************************************************************
-	Create a new window of the specified type
+    Create a new window of the specified type
 *************************************************************************/
 Window* WindowManager::createWindow( const String& type, const String& name /*= ""*/, const String& prefix /*= ""*/ )
 {
+    // only allow creation of Window objects if we are in unlocked state
+    if (isLocked())
+        throw InvalidRequestException("WindowManager::createWindow - "
+                                      "WindowManager is in the locked state.");
+
     // Make sure that a non-empty name gets passed to the factory
     String finalName(prefix + name);
     // Still empty?
@@ -91,17 +103,21 @@ Window* WindowManager::createWindow( const String& type, const String& name /*=
         finalName = generateUniqueWindowName();
     }
 
-	if (isWindowPresent(finalName))
-	{
-		throw AlreadyExistsException("WindowManager::createWindow - A Window object with the name '" + finalName +"' already exists within the system.");
-	}
+    if (isWindowPresent(finalName))
+    {
+        throw AlreadyExistsException("WindowManager::createWindow - A Window object with the name '" + finalName +"' already exists within the system.");
+    }
 
     WindowFactoryManager& wfMgr = WindowFactoryManager::getSingleton();
     WindowFactory* factory = wfMgr.getFactory(type);
 
     Window* newWindow = factory->createWindow(finalName);
-	newWindow->setPrefix(prefix);
-    Logger::getSingleton().logEvent("Window '" + finalName +"' of type '" + type + "' has been created.", Informative);
+    newWindow->setPrefix(prefix);
+
+    char addr_buff[32];
+    sprintf(addr_buff, "(%p)", static_cast<void*>(newWindow));
+    Logger::getSingleton().logEvent("Window '" + finalName +"' of type '" +
+        type + "' has been created. " + addr_buff, Informative);
 
     // see if we need to assign a look to this window
     if (wfMgr.isFalagardMappedType(type))
@@ -114,40 +130,40 @@ Window* WindowManager::createWindow( const String& type, const String& name /*=
         newWindow->setLookNFeel(fwm.d_lookName);
     }
 
-	d_windowRegistry[finalName] = newWindow;
+    d_windowRegistry[finalName] = newWindow;
 
-	return newWindow;
+    return newWindow;
 }
 
 
 /*************************************************************************
-	Destroy the given window by pointer
+    Destroy the given window by pointer
 *************************************************************************/
 void WindowManager::destroyWindow(Window* window)
 {
-	if (window)
-	{
-		// this is done because the name is used for the log after the window is destroyed,
-		// if we just did getName() we would get a const ref to the Window's internal name
-		// string which is destroyed along with the window so wouldn't exist when the log tried
-		// to use it (as I soon discovered).
-		String name = window->getName();
+    if (window)
+    {
+        // this is done because the name is used for the log after the window is destroyed,
+        // if we just did getName() we would get a const ref to the Window's internal name
+        // string which is destroyed along with the window so wouldn't exist when the log tried
+        // to use it (as I soon discovered).
+        String name = window->getName();
 
-		destroyWindow(name);
-	}
+        destroyWindow(name);
+    }
 
 }
 
 
 /*************************************************************************
-	Destroy the given window by name
+    Destroy the given window by name
 *************************************************************************/
 void WindowManager::destroyWindow(const String& window)
 {
-	WindowRegistry::iterator wndpos = d_windowRegistry.find(window);
+    WindowRegistry::iterator wndpos = d_windowRegistry.find(window);
 
-	if (wndpos != d_windowRegistry.end())
-	{
+    if (wndpos != d_windowRegistry.end())
+    {
         Window* wnd = wndpos->second;
 
         // remove entry from the WindowRegistry.
@@ -162,95 +178,98 @@ void WindowManager::destroyWindow(const String& window)
         // notify system object of the window destruction
         System::getSingleton().notifyWindowDestroyed(wnd);
 
-		Logger::getSingleton().logEvent("Window '" + window + "' has been added to dead pool.", Informative);
-	}
+        char addr_buff[32];
+        sprintf(addr_buff, "(%p)", static_cast<void*>(wnd));
+        Logger::getSingleton().logEvent("Window '" + window + "' has been "
+            "added to dead pool. " + addr_buff, Informative);
+    }
 
 }
 
 
 /*************************************************************************
-	Return a pointer to the named window
+    Return a pointer to the named window
 *************************************************************************/
 Window* WindowManager::getWindow(const String& name) const
 {
-	WindowRegistry::const_iterator pos = d_windowRegistry.find(name);
+    WindowRegistry::const_iterator pos = d_windowRegistry.find(name);
 
-	if (pos == d_windowRegistry.end())
-	{
-		throw UnknownObjectException("WindowManager::getWindow - A Window object with the name '" + name +"' does not exist within the system");
-	}
+    if (pos == d_windowRegistry.end())
+    {
+        throw UnknownObjectException("WindowManager::getWindow - A Window object with the name '" + name +"' does not exist within the system");
+    }
 
-	return pos->second;
+    return pos->second;
 }
 
 
 /*************************************************************************
-	Return true if a window with the given name is present
+    Return true if a window with the given name is present
 *************************************************************************/
 bool WindowManager::isWindowPresent(const String& name) const
 {
-	return (d_windowRegistry.find(name) != d_windowRegistry.end());
+    return (d_windowRegistry.find(name) != d_windowRegistry.end());
 }
 
 
 /*************************************************************************
-	Destroy all Window objects
+    Destroy all Window objects
 *************************************************************************/
 void WindowManager::destroyAllWindows(void)
 {
-	String window_name;
-	while (!d_windowRegistry.empty())
-	{
-		window_name = d_windowRegistry.begin()->first;
-		destroyWindow(window_name);
-	}
+    String window_name;
+    while (!d_windowRegistry.empty())
+    {
+        window_name = d_windowRegistry.begin()->first;
+        destroyWindow(window_name);
+    }
 
 }
 
 
 /*************************************************************************
-	Creates a set of windows (a Gui layout) from the information in the
-	specified XML file.	
+    Creates a set of windows (a Gui layout) from the information in the
+    specified XML file.
 *************************************************************************/
 Window* WindowManager::loadWindowLayout(const String& filename, const String& name_prefix, const String& resourceGroup, PropertyCallback* callback, void* userdata)
 {
-	if (filename.empty())
-	{
-		throw InvalidRequestException("WindowManager::loadWindowLayout - Filename supplied for gui-layout loading must be valid.");
-	}
+    if (filename.empty())
+    {
+        throw InvalidRequestException("WindowManager::loadWindowLayout - Filename supplied for gui-layout loading must be valid.");
+    }
 
-	// log the fact we are about to load a layout
-	Logger::getSingleton().logEvent("---- Beginning loading of GUI layout from '" + filename + "' ----", Informative);
+    // log the fact we are about to load a layout
+    Logger::getSingleton().logEvent("---- Beginning loading of GUI layout from '" + filename + "' ----", Informative);
 
     // create handler object
     GUILayout_xmlHandler handler(name_prefix, callback, userdata);
 
-	// do parse (which uses handler to create actual data)
-	try
-	{
+    // do parse (which uses handler to create actual data)
+    try
+    {
         System::getSingleton().getXMLParser()->parseXMLFile(handler,
             filename, GUILayoutSchemaName, resourceGroup.empty() ? d_defaultResourceGroup : resourceGroup);
-	}
-	catch(...)
-	{
+    }
+    catch(...)
+    {
         Logger::getSingleton().logEvent("WindowManager::loadWindowLayout - loading of layout from file '" + filename +"' failed.", Errors);
         throw;
-	}
+    }
 
     // log the completion of loading
     Logger::getSingleton().logEvent("---- Successfully completed loading of GUI layout from '" + filename + "' ----", Standard);
 
-	return handler.getLayoutRootWindow();
+    return handler.getLayoutRootWindow();
 }
 
 Window* WindowManager::loadWindowLayout( const String& filename, bool generateRandomPrefix )
 {
-	//We really just use the bool to get rid of ambiguity with the other loadWindowLayout. There is no difference between
-	//calling this loadWindowLayout and setting GRP to false, and calling the other one with no argument
-	if(generateRandomPrefix)
-		return loadWindowLayout(filename,generateUniqueWindowPrefix());  
-	
-		return loadWindowLayout(filename);
+    //We really just use the bool to get rid of ambiguity with the other loadWindowLayout. There is no difference between
+    //calling this loadWindowLayout and setting GRP to false, and calling the other one with no argument
+    if(generateRandomPrefix)
+        return loadWindowLayout(filename,generateUniqueWindowPrefix());
+
+        return loadWindowLayout(filename);
 }
 bool WindowManager::isDeadPoolEmpty(void) const
 {
@@ -270,7 +289,7 @@ void WindowManager::cleanDeadPool(void)
         WindowFactory* factory = WindowFactoryManager::getSingleton().getFactory((*curr)->getType());
         factory->destroyWindow(*curr);
     }
-    
+
     // all done here, so clear all pointers from dead pool
     d_deathrow.clear();
 }
@@ -317,19 +336,19 @@ String WindowManager::generateUniqueWindowName()
 
 CEGUI::String WindowManager::generateUniqueWindowPrefix()
 {
-	std::ostringstream prefix;
-	prefix << d_uid_counter << "_";
-	
-	// update counter for next time
-	unsigned long old_uid = d_uid_counter;
-	++d_uid_counter;
+    std::ostringstream prefix;
+    prefix << d_uid_counter << "_";
 
-	// log if we ever wrap-around (which should be pretty unlikely)
-	if (d_uid_counter < old_uid)
-		Logger::getSingleton().logEvent("UID counter for generated window names has wrapped around - the fun shall now commence!");
+    // update counter for next time
+    unsigned long old_uid = d_uid_counter;
+    ++d_uid_counter;
 
-	//return generated prefix
-	return String(prefix.str());
+    // log if we ever wrap-around (which should be pretty unlikely)
+    if (d_uid_counter < old_uid)
+        Logger::getSingleton().logEvent("UID counter for generated window names has wrapped around - the fun shall now commence!");
+
+    //return generated prefix
+    return String(prefix.str());
 
 }
 
@@ -370,12 +389,12 @@ void WindowManager::renameWindow(Window* window, const String& new_name)
 }
 
 /*************************************************************************
-	Return a WindowManager::WindowIterator object to iterate over the
-	currently defined Windows.
+    Return a WindowManager::WindowIterator object to iterate over the
+    currently defined Windows.
 *************************************************************************/
 WindowManager::WindowIterator WindowManager::getIterator(void) const
 {
-	return WindowIterator(d_windowRegistry.begin(), d_windowRegistry.end());
+    return WindowIterator(d_windowRegistry.begin(), d_windowRegistry.end());
 }
 
 /*************************************************************************
@@ -394,4 +413,25 @@ void WindowManager::DEBUG_dumpWindowNames(String zone)
     Logger::getSingleton().logEvent("-----------------");
 }
 
+//----------------------------------------------------------------------------//
+void WindowManager::lock()
+{
+    ++d_lockCount;
+}
+
+//----------------------------------------------------------------------------//
+void WindowManager::unlock()
+{
+    if (d_lockCount > 0)
+        --d_lockCount;
+}
+
+//----------------------------------------------------------------------------//
+bool WindowManager::isLocked() const
+{
+    return d_lockCount != 0;
+}
+
+//----------------------------------------------------------------------------//
+
 } // End of  CEGUI namespace section
