@@ -2,7 +2,7 @@
 	filename: 	CEGUIcolour.cpp
 	created:	20/8/2004
 	author:		Paul D Turner (with code from Jeff Leigh)
-	
+
 	purpose:	Implementation of colour class methods.
 *************************************************************************/
 /***************************************************************************
@@ -146,15 +146,6 @@ void colour::setARGB(argb_t argb)
 {
 	d_argb = argb;
 
-#ifdef __BIG_ENDIAN__
-    d_alpha	= static_cast<float>(argb & 0xFF) / 255.0f;
-	argb >>= 8;
-	d_red	= static_cast<float>(argb & 0xFF) / 255.0f;
-	argb >>= 8;
-	d_green	= static_cast<float>(argb & 0xFF) / 255.0f;
-	argb >>= 8;
-	d_blue	= static_cast<float>(argb & 0xFF) / 255.0f;
-#else
 	d_blue	= static_cast<float>(argb & 0xFF) / 255.0f;
 	argb >>= 8;
 	d_green	= static_cast<float>(argb & 0xFF) / 255.0f;
@@ -162,7 +153,6 @@ void colour::setARGB(argb_t argb)
 	d_red	= static_cast<float>(argb & 0xFF) / 255.0f;
 	argb >>= 8;
 	d_alpha	= static_cast<float>(argb & 0xFF) / 255.0f;
-#endif
 
 	d_argbValid = true;
 }
@@ -244,21 +234,12 @@ void colour::setHSL(float hue, float saturation, float luminance, float alpha)
 
 argb_t colour::calculateARGB(void) const
 {
-#ifdef __BIG_ENDIAN__
-	return (
-		static_cast<argb_t>(d_blue * 255) << 24 |
-		static_cast<argb_t>(d_green * 255) << 16 |
-		static_cast<argb_t>(d_red * 255) << 8 |
-		static_cast<argb_t>(d_alpha * 255)
-	);
-#else
     return (
 		static_cast<argb_t>(d_alpha * 255) << 24 |
 		static_cast<argb_t>(d_red * 255) << 16 |
 		static_cast<argb_t>(d_green * 255) << 8 |
 		static_cast<argb_t>(d_blue * 255)
 	);
-#endif
 }
 
 
