@@ -378,7 +378,7 @@ namespace CEGUI
             bool wasEnabled = d_enabled;
             d_enabled = false;
             // find out which child of root window has the mouse in it
-            Window* eventWindow = root->getChildAtPosition(MouseCursor::getSingleton().getPosition());
+            Window* eventWindow = root->getTargetChildAtPosition(MouseCursor::getSingleton().getPosition());
             d_enabled = wasEnabled;
 
             // use root itself if no child was hit
@@ -444,8 +444,12 @@ namespace CEGUI
         // update to new target
         d_dropTarget = e.window;
 
+        while ((d_dropTarget != 0) && !d_dropTarget->isDragDropTarget())
+            d_dropTarget = d_dropTarget->getParent();
+
         // Notify new target window that someone has dragged a DragContainer over it
-        d_dropTarget->notifyDragDropItemEnters(this);
+        if (d_dropTarget)
+            d_dropTarget->notifyDragDropItemEnters(this);
     }
 
 } // End of  CEGUI namespace section
