@@ -1,33 +1,37 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIEditbox.cpp
 	created:	13/4/2004
 	author:		Paul D Turner
 	
 	purpose:	Implementation of Editbox base class widget
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #include "elements/CEGUIEditbox.h"
 #include "CEGUITextUtils.h"
 #include "CEGUIExceptions.h"
 #include "CEGUIFont.h"
-#include "../pcre/pcre.h"
+#include <pcre.h>
 #include <string.h>
 
 
@@ -35,6 +39,7 @@
 namespace CEGUI
 {
 const String Editbox::EventNamespace("Editbox");
+const String Editbox::WidgetTypeName("CEGUI/Editbox");
 
 /*!
 \brief
@@ -58,6 +63,14 @@ struct RegexValidator
 	pcre* d_regex;
 };
 
+/*************************************************************************
+    EditboxWindowRenderer
+*************************************************************************/
+EditboxWindowRenderer::EditboxWindowRenderer(const String& name) :
+    WindowRenderer(name, Editbox::EventNamespace)
+{
+}
+
 /*************************************************************************
 	TODO:
 
@@ -75,36 +88,22 @@ EditboxProperties::CaratIndex				Editbox::d_caratIndexProperty;
 EditboxProperties::SelectionStart			Editbox::d_selectionStartProperty;
 EditboxProperties::SelectionLength			Editbox::d_selectionLengthProperty;
 EditboxProperties::MaxTextLength			Editbox::d_maxTextLengthProperty;
-EditboxProperties::NormalTextColour			Editbox::d_normalTextColourProperty;
-EditboxProperties::SelectedTextColour		Editbox::d_selectedTextColourProperty;
-EditboxProperties::ActiveSelectionColour	Editbox::d_activeSelectionColourProperty;
-EditboxProperties::InactiveSelectionColour	Editbox::d_inactiveSelectionColourProperty;
-
-
-/*************************************************************************
-	Constants
-*************************************************************************/
-// default colours
-const argb_t Editbox::DefaultNormalTextColour			= 0xFFFFFFFF;
-const argb_t Editbox::DefaultSelectedTextColour			= 0xFF000000;
-const argb_t Editbox::DefaultNormalSelectionColour		= 0xFF6060FF;
-const argb_t Editbox::DefaultInactiveSelectionColour	= 0xFF808080;
 
 
 /*************************************************************************
 	Event name constants
 *************************************************************************/
-const String Editbox::EventReadOnlyModeChanged( (utf8*)"ReadOnlyChanged" );
-const String Editbox::EventMaskedRenderingModeChanged( (utf8*)"MaskRenderChanged" );
-const String Editbox::EventMaskCodePointChanged( (utf8*)"MaskCPChanged" );
-const String Editbox::EventValidationStringChanged( (utf8*)"ValidatorChanged" );
-const String Editbox::EventMaximumTextLengthChanged( (utf8*)"MaxTextLenChanged" );
-const String Editbox::EventTextInvalidated( (utf8*)"TextInvalidated" );
-const String Editbox::EventInvalidEntryAttempted( (utf8*)"InvalidInputAttempt" );
-const String Editbox::EventCaratMoved( (utf8*)"TextCaratMoved" );
-const String Editbox::EventTextSelectionChanged( (utf8*)"TextSelectChanged" );
-const String Editbox::EventEditboxFull( (utf8*)"EditboxFull" );
-const String Editbox::EventTextAccepted( (utf8*)"TextAccepted" );
+const String Editbox::EventReadOnlyModeChanged( "ReadOnlyChanged" );
+const String Editbox::EventMaskedRenderingModeChanged( "MaskRenderChanged" );
+const String Editbox::EventMaskCodePointChanged( "MaskCPChanged" );
+const String Editbox::EventValidationStringChanged( "ValidatorChanged" );
+const String Editbox::EventMaximumTextLengthChanged( "MaxTextLenChanged" );
+const String Editbox::EventTextInvalidated( "TextInvalidated" );
+const String Editbox::EventInvalidEntryAttempted( "InvalidInputAttempt" );
+const String Editbox::EventCaratMoved( "TextCaratMoved" );
+const String Editbox::EventTextSelectionChanged( "TextSelectChanged" );
+const String Editbox::EventEditboxFull( "EditboxFull" );
+const String Editbox::EventTextAccepted( "TextAccepted" );
 
 
 /*************************************************************************
@@ -119,19 +118,13 @@ Editbox::Editbox(const String& type, const String& name) :
 	d_caratPos(0),
 	d_selectionStart(0),
 	d_selectionEnd(0),
-	d_dragging(false),
-	d_normalTextColour(DefaultNormalTextColour),
-	d_selectTextColour(DefaultSelectedTextColour),
-	d_selectBrushColour(DefaultNormalSelectionColour),
-	d_inactiveSelectBrushColour(DefaultInactiveSelectionColour)
+    d_validator(new RegexValidator),
+	d_dragging(false)
 {
-	d_validator = new RegexValidator;
-
-	addEditboxEvents();
 	addEditboxProperties();
 
 	// default to accepting all characters
-	setValidationString((utf8*)".*");
+	setValidationString(".*");
 }
 
 
@@ -428,7 +421,7 @@ bool Editbox::isStringValid(const String& str) const
 	const char* utf8str = str.c_str();
 	int	match[3];
 	int len = static_cast<int>(strlen(utf8str));
-	int result = pcre_exec(d_validator->d_regex, NULL, utf8str, len, 0, 0, match, 3);
+	int result = pcre_exec(d_validator->d_regex, 0, utf8str, len, 0, 0, match, 3);
 
 	if (result >= 0)
 	{
@@ -602,6 +595,9 @@ void Editbox::onCharacter(KeyEventArgs& e)
 
                 // set text to the newly modified string
 				setText(tmp);
+
+                // char was accepted into the Editbox - mark event as handled.
+                e.handled = true;
 			}
 			else
 			{
@@ -620,7 +616,7 @@ void Editbox::onCharacter(KeyEventArgs& e)
 
 	}
 
-	e.handled = true;
+    // event was (possibly) not handled
 }
 
 
@@ -939,20 +935,6 @@ void Editbox::handleEnd(uint sysKeys)
 }
 
 
-/*************************************************************************
-	Add edit box specific events
-*************************************************************************/
-void Editbox::addEditboxEvents(void)
-{
-	addEvent(EventReadOnlyModeChanged);				addEvent(EventMaskedRenderingModeChanged);
-	addEvent(EventMaskCodePointChanged);			addEvent(EventValidationStringChanged);
-	addEvent(EventMaximumTextLengthChanged);		addEvent(EventTextInvalidated);
-	addEvent(EventInvalidEntryAttempted);			addEvent(EventCaratMoved);
-	addEvent(EventTextSelectionChanged);			addEvent(EventEditboxFull);
-	addEvent(EventTextAccepted);
-}
-
-
 /*************************************************************************
 	Event fired internally when the read only state of the Editbox has
 	been changed
@@ -1070,50 +1052,6 @@ void Editbox::onTextAcceptedEvent(WindowEventArgs& e)
 }
 
 
-/*************************************************************************
-	Set the colour to be used for rendering Editbox text in the normal,
-	unselected state.	
-*************************************************************************/
-void Editbox::setNormalTextColour(const colour& col)
-{
-	d_normalTextColour = col;
-	requestRedraw();
-}
-
-
-/*************************************************************************
-	Set the colour to be used for rendering the Editbox text when within
-	the selected region.
-*************************************************************************/
-void Editbox::setSelectedTextColour(const colour& col)
-{
-	d_selectTextColour = col;
-	requestRedraw();
-}
-
-
-/*************************************************************************
-	Set the colour to be used for rendering the Editbox selection highlight
-	when the Editbox is active.
-*************************************************************************/
-void Editbox::setNormalSelectBrushColour(const colour& col)
-{
-	d_selectBrushColour = col;
-	requestRedraw();
-}
-
-
-/*************************************************************************
-	Set the colour to be used for rendering the Editbox selection highlight
-	when the Editbox is inactive.
-*************************************************************************/
-void Editbox::setInactiveSelectBrushColour(const colour& col)
-{
-	d_inactiveSelectBrushColour = col;
-	requestRedraw();
-}
-
-
 /*************************************************************************
 	Handler for when text is changed programmatically
 *************************************************************************/
@@ -1147,11 +1085,24 @@ void Editbox::addEditboxProperties(void)
 	addProperty(&d_selectionStartProperty);
 	addProperty(&d_selectionLengthProperty);
 	addProperty(&d_maxTextLengthProperty);
-	addProperty(&d_normalTextColourProperty);
-	addProperty(&d_selectedTextColourProperty);
-	addProperty(&d_activeSelectionColourProperty);
-	addProperty(&d_inactiveSelectionColourProperty);
 }
 
+/*************************************************************************
+    Return the text code point index that is rendered closest to the
+    given screen position
+*************************************************************************/
+size_t Editbox::getTextIndexFromPosition(const Point& pt) const
+{
+    if (d_windowRenderer != 0)
+    {
+        EditboxWindowRenderer* wr = (EditboxWindowRenderer*)d_windowRenderer;
+        return wr->getTextIndexFromPosition(pt);
+    }
+    else
+    {
+        //return getTextIndexFromPosition_impl(pt);
+        throw InvalidRequestException("Editbox::getTextIndexFromPosition - This function must be implemented by the window renderer");
+    }
+}
 
 } // End of  CEGUI namespace section
