@@ -1,36 +1,44 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIListHeaderSegment.cpp
 	created:	15/6/2004
 	author:		Paul D Turner
 	
 	purpose:	Implementation of List header segment widget.
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #include "elements/CEGUIListHeaderSegment.h"
 #include "CEGUIMouseCursor.h"
-
+#include "CEGUICoordConverter.h"
+#include "CEGUIImagesetManager.h"
+#include "CEGUIImageset.h"
 
 // Start of CEGUI namespace section
 namespace CEGUI
 {
 const String ListHeaderSegment::EventNamespace("ListHeaderSegment");
+const String ListHeaderSegment::WidgetTypeName("CEGUI/ListHeaderSegment");
+
 
 /*************************************************************************
 	Properties for this class
@@ -39,22 +47,24 @@ ListHeaderSegmentProperties::Clickable		ListHeaderSegment::d_clickableProperty;
 ListHeaderSegmentProperties::Dragable		ListHeaderSegment::d_dragableProperty;
 ListHeaderSegmentProperties::Sizable		ListHeaderSegment::d_sizableProperty;
 ListHeaderSegmentProperties::SortDirection	ListHeaderSegment::d_sortDirectionProperty;
+ListHeaderSegmentProperties::SizingCursorImage   ListHeaderSegment::d_sizingCursorProperty;
+ListHeaderSegmentProperties::MovingCursorImage   ListHeaderSegment::d_movingCursorProperty;
 
 
 /*************************************************************************
 	Constants
 *************************************************************************/
 // Event names
-const String ListHeaderSegment::EventSegmentClicked( (utf8*)"SegmentClicked" );
-const String ListHeaderSegment::EventSplitterDoubleClicked( (utf8*)"SplitterDoubleClicked" );
-const String ListHeaderSegment::EventSizingSettingChanged( (utf8*)"SizingSettingChanged" );
-const String ListHeaderSegment::EventSortDirectionChanged( (utf8*)"SortDirectionChanged" );
-const String ListHeaderSegment::EventMovableSettingChanged( (utf8*)"MovableSettingChanged" );
-const String ListHeaderSegment::EventSegmentDragStart( (utf8*)"SegmentDragStart" );
-const String ListHeaderSegment::EventSegmentDragStop( (utf8*)"SegmentDragStop" );
-const String ListHeaderSegment::EventSegmentDragPositionChanged( (utf8*)"SegmentDragPositionChanged" );
-const String ListHeaderSegment::EventSegmentSized( (utf8*)"SegmentSized" );
-const String ListHeaderSegment::EventClickableSettingChanged( (utf8*)"ClickableSettingChanged" );
+const String ListHeaderSegment::EventSegmentClicked( "SegmentClicked" );
+const String ListHeaderSegment::EventSplitterDoubleClicked( "SplitterDoubleClicked" );
+const String ListHeaderSegment::EventSizingSettingChanged( "SizingSettingChanged" );
+const String ListHeaderSegment::EventSortDirectionChanged( "SortDirectionChanged" );
+const String ListHeaderSegment::EventMovableSettingChanged( "MovableSettingChanged" );
+const String ListHeaderSegment::EventSegmentDragStart( "SegmentDragStart" );
+const String ListHeaderSegment::EventSegmentDragStop( "SegmentDragStop" );
+const String ListHeaderSegment::EventSegmentDragPositionChanged( "SegmentDragPositionChanged" );
+const String ListHeaderSegment::EventSegmentSized( "SegmentSized" );
+const String ListHeaderSegment::EventClickableSettingChanged( "ClickableSettingChanged" );
 
 // Defaults
 const float	ListHeaderSegment::DefaultSizingArea	= 8.0f;
@@ -66,8 +76,8 @@ const float	ListHeaderSegment::SegmentMoveThreshold	= 12.0f;
 *************************************************************************/
 ListHeaderSegment::ListHeaderSegment(const String& type, const String& name) :
 	Window(type, name),
-	d_sizingMouseCursor(NULL),
-	d_movingMouseCursor(NULL),
+	d_sizingMouseCursor(0),
+	d_movingMouseCursor(0),
 	d_splitterSize(DefaultSizingArea),
 	d_splitterHover(false),
 	d_dragSizing(false),
@@ -79,7 +89,6 @@ ListHeaderSegment::ListHeaderSegment(const String& type, const String& name) :
 	d_dragMoving(false),
 	d_allowClicks(true)
 {
-	addHeaderSegmentEvents();
 	addHeaderSegmentProperties();
 }
 
@@ -164,25 +173,6 @@ void ListHeaderSegment::setClickable(bool setting)
 }
 
 
-/*************************************************************************
-	Add list header segment specific events
-*************************************************************************/
-void ListHeaderSegment::addHeaderSegmentEvents(void)
-{
-	addEvent(EventSortDirectionChanged);
-	addEvent(EventSizingSettingChanged);
-	addEvent(EventSplitterDoubleClicked);
-	addEvent(EventSegmentClicked);
-	addEvent(EventSegmentDragStart);
-	addEvent(EventSegmentDragStop);
-	addEvent(EventSegmentDragPositionChanged);
-	addEvent(EventMovableSettingChanged);
-	addEvent(EventSegmentSized);
-	addEvent(EventClickableSettingChanged);
-}
-
-
-
 /*************************************************************************
 	Handler called when segment is clicked.	
 *************************************************************************/
@@ -285,7 +275,7 @@ void ListHeaderSegment::doDragSizing(const Point& local_mouse)
     float delta = local_mouse.d_x - d_dragPoint.d_x;
 
     // store this so we can work out how much size actually changed
-    float orgWidth = getAbsoluteWidth();
+    float orgWidth = d_pixelSize.d_width;
 
     // ensure that we only size to the set constraints.
     //
@@ -303,10 +293,10 @@ void ListHeaderSegment::doDragSizing(const Point& local_mouse)
     
     // update segment area rect
     URect area(d_area.d_min.d_x, d_area.d_min.d_y, d_area.d_max.d_x + UDim(0,PixelAligned(delta)), d_area.d_max.d_y);
-    setWindowArea_impl(area.d_min, area.getSize());
+    setArea_impl(area.d_min, area.getSize());
 
     // move the dragging point so mouse remains 'attached' to edge of segment
-    d_dragPoint.d_x += getAbsoluteWidth() - orgWidth;
+    d_dragPoint.d_x += d_pixelSize.d_width - orgWidth;
 
     WindowEventArgs args(this);
     onSegmentSized(args);
@@ -444,12 +434,7 @@ void ListHeaderSegment::onMouseMove(MouseEventArgs& e)
 	//
 	// convert mouse position to something local
 	//
-	Point localMousePos(screenToWindow(e.position));
-
-	if (getMetricsMode() == Relative)
-	{
-		localMousePos = relativeToAbsolute(localMousePos);
-	}
+	Point localMousePos(CoordConverter::screenToWindow(*this, e.position));
 
 	// handle drag sizing
 	if (d_dragSizing)
@@ -465,7 +450,7 @@ void ListHeaderSegment::onMouseMove(MouseEventArgs& e)
 	else if (isHit(e.position))
 	{
 		// mouse in sizing area & sizing is enabled
-		if ((localMousePos.d_x > (getAbsoluteWidth() - d_splitterSize)) && d_sizingEnabled)
+		if ((localMousePos.d_x > (d_pixelSize.d_width - d_splitterSize)) && d_sizingEnabled)
 		{
 			initSizingHoverState();
 		}
@@ -525,12 +510,7 @@ void ListHeaderSegment::onMouseButtonDown(MouseEventArgs& e)
 		if (captureInput())
 		{
 			// get position of mouse as co-ordinates local to this window.
-			Point localPos(screenToWindow(e.position));
-
-			if (getMetricsMode() == Relative)
-			{
-				localPos = relativeToAbsolute(localPos);
-			}
+			Point localPos(CoordConverter::screenToWindow(*this, e.position));
 
 			// store drag point for possible sizing or moving operation.
 			d_dragPoint = localPos;
@@ -650,8 +630,38 @@ void ListHeaderSegment::addHeaderSegmentProperties(void)
 	addProperty(&d_sizableProperty);
 	addProperty(&d_dragableProperty);
 	addProperty(&d_sortDirectionProperty);
+    addProperty(&d_sizingCursorProperty);
+    addProperty(&d_movingCursorProperty);
 }
 
+const Image* ListHeaderSegment::getSizingCursorImage() const
+{
+    return d_sizingMouseCursor;
+}
 
+void ListHeaderSegment::setSizingCursorImage(const Image* image)
+{
+    d_sizingMouseCursor = image;
+}
+
+void ListHeaderSegment::setSizingCursorImage(const String& imageset, const String& image)
+{
+    d_sizingMouseCursor = &ImagesetManager::getSingleton().getImageset(imageset)->getImage(image);
+}
+
+const Image* ListHeaderSegment::getMovingCursorImage() const
+{
+    return d_movingMouseCursor;
+}
+
+void ListHeaderSegment::setMovingCursorImage(const Image* image)
+{
+    d_movingMouseCursor = image;
+}
+
+void ListHeaderSegment::setMovingCursorImage(const String& imageset, const String& image)
+{
+    d_movingMouseCursor = &ImagesetManager::getSingleton().getImageset(imageset)->getImage(image);
+}
 
 } // End of  CEGUI namespace section
