@@ -1,28 +1,32 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIListboxTextItem.cpp
 	created:	12/6/2004
 	author:		Paul D Turner
 	
 	purpose:	Implementation of List box text items
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #include "elements/CEGUIListboxTextItem.h"
 #include "CEGUIFontManager.h"
 #include "CEGUIFont.h"
@@ -44,7 +48,7 @@ const colour	ListboxTextItem::DefaultTextColour		= 0xFFFFFFFF;
 ListboxTextItem::ListboxTextItem(const String& text, uint item_id, void* item_data, bool disabled, bool auto_delete) :
 	ListboxItem(text, item_id, item_data, disabled, auto_delete),
 	d_textCols(DefaultTextColour, DefaultTextColour, DefaultTextColour, DefaultTextColour),
-	d_font(NULL)
+	d_font(0)
 {
 }
 
@@ -52,15 +56,15 @@ ListboxTextItem::ListboxTextItem(const String& text, uint item_id, void* item_da
 /*************************************************************************
 	Return a pointer to the font being used by this ListboxTextItem
 *************************************************************************/
-const Font* ListboxTextItem::getFont(void) const
+Font* ListboxTextItem::getFont(void) const
 {
 	// prefer out own font
-	if (d_font != NULL)
+	if (d_font)
 	{
 		return d_font;
 	}
 	// try our owner window's font setting (may be null if owner uses no existant default font)
-	else if (d_owner != NULL)
+	else if (d_owner)
 	{
 		return d_owner->getFont();
 	}
@@ -88,12 +92,12 @@ Size ListboxTextItem::getPixelSize(void) const
 {
 	Size tmp(0,0);
 
-	const Font* fnt = getFont();
+	Font* fnt = getFont();
 
-	if (fnt != NULL)
+	if (fnt)
 	{
-		tmp.d_height	= PixelAligned(fnt->getLineSpacing());
-		tmp.d_width		= PixelAligned(fnt->getTextExtent(d_itemText));
+		tmp.d_height = PixelAligned(fnt->getLineSpacing());
+		tmp.d_width = PixelAligned(fnt->getTextExtent(d_itemText));
 	}
 
 	return tmp;
@@ -105,17 +109,17 @@ Size ListboxTextItem::getPixelSize(void) const
 *************************************************************************/
 void ListboxTextItem::draw(const Vector3& position, float alpha, const Rect& clipper) const
 {
-	if (d_selected && (d_selectBrush != NULL))
+	if (d_selected && (d_selectBrush != 0))
 	{
 		d_selectBrush->draw(clipper, position.d_z, clipper, getModulateAlphaColourRect(d_selectCols, alpha));
 	}
 
-	const Font* fnt = getFont();
+	Font* fnt = getFont();
 
-	if (fnt != NULL)
+	if (fnt)
 	{
         Vector3 finalPos(position);
-        finalPos.d_y -= PixelAligned((fnt->getLineSpacing() - fnt->getBaseline()) * 0.5f);
+        finalPos.d_y += PixelAligned((fnt->getLineSpacing() - fnt->getFontHeight()) * 0.5f);
 		fnt->drawText(d_itemText, finalPos, clipper, getModulateAlphaColourRect(d_textCols, alpha));
 	}
 
@@ -128,12 +132,12 @@ void ListboxTextItem::draw(RenderCache& cache,const Rect& targetRect, float zBas
         cache.cacheImage(*d_selectBrush, targetRect, zBase, getModulateAlphaColourRect(d_selectCols, alpha), clipper);
     }
 
-    const Font* font = getFont();
+    Font* font = getFont();
 
     if (font)
     {
         Rect finalPos(targetRect);
-        finalPos.d_top -= (font->getLineSpacing() - font->getBaseline()) * 0.5f;
+        finalPos.d_top += PixelAligned((font->getLineSpacing() - font->getFontHeight()) * 0.5f);
         cache.cacheText(d_itemText, font, LeftAligned, finalPos, zBase, getModulateAlphaColourRect(d_textCols, alpha), clipper);
     }
 }
