@@ -1,42 +1,48 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUITitlebar.cpp
 	created:	25/4/2004
 	author:		Paul D Turner
 	
 	purpose:	Implementation of common Titlebar parts.
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #include "elements/CEGUITitlebar.h"
 #include "elements/CEGUIFrameWindow.h"
 #include "CEGUIMouseCursor.h"
+#include "CEGUICoordConverter.h"
 
 // Start of CEGUI namespace section
 namespace CEGUI
 {
 const String Titlebar::EventNamespace("Titlebar");
+const String Titlebar::WidgetTypeName("CEGUI/Titlebar");
+
 
 /*************************************************************************
 	Definition of Properties for this class
 *************************************************************************/
 TitlebarProperties::DraggingEnabled	Titlebar::d_dragEnabledProperty;
-TitlebarProperties::CaptionColour	Titlebar::d_captionColourProperty;
 
 
 /*************************************************************************
@@ -102,14 +108,9 @@ void Titlebar::onMouseMove(MouseEventArgs& e)
 	// Base class processing.
 	Window::onMouseMove(e);
 
-	if (d_dragging && (d_parent != NULL))
+	if (d_dragging && (d_parent != 0))
 	{
-		Vector2 delta(screenToWindow(e.position));
-
-		if (getMetricsMode() == Relative)
-		{
-			delta = relativeToAbsolute(delta);
-		}
+		Vector2 delta(CoordConverter::screenToWindow(*this, e.position));
 
 		// calculate amount that window has been moved
 		delta -= d_dragPoint;
@@ -132,19 +133,14 @@ void Titlebar::onMouseButtonDown(MouseEventArgs& e)
 
 	if (e.button == LeftButton)
 	{
-		if ((d_parent != NULL) && d_dragEnabled)
+		if ((d_parent != 0) && d_dragEnabled)
 		{
 			// we want all mouse inputs from now on
 			if (captureInput())
 			{
 				// initialise the dragging state
 				d_dragging = true;
-				d_dragPoint = screenToWindow(e.position);
-
-				if (getMetricsMode() == Relative)
-				{
-					d_dragPoint = relativeToAbsolute(d_dragPoint);
-				}
+				d_dragPoint = CoordConverter::screenToWindow(*this, e.position);
 
 				// store old constraint area
 				d_oldCursorArea = MouseCursor::getSingleton().getConstraintArea();
@@ -152,7 +148,7 @@ void Titlebar::onMouseButtonDown(MouseEventArgs& e)
 				// setup new constraint area to be the intersection of the old area and our grand-parent's clipped inner-area
 				Rect constrainArea;
 
-				if ((d_parent == NULL) || (d_parent->getParent() == NULL))
+				if ((d_parent == 0) || (d_parent->getParent() == 0))
 				{
 					constrainArea = System::getSingleton().getRenderer()->getRect().getIntersection(d_oldCursorArea);
 				}
@@ -199,7 +195,7 @@ void Titlebar::onMouseDoubleClicked(MouseEventArgs& e)
 	if (e.button == LeftButton)
 	{
 		// if we do not have a parent window, then obviously nothing should happen.
-		if (d_parent != NULL)
+		if (d_parent)
 		{
 			// we should only ever be attached to a FrameWindow (or derived) class
 			((FrameWindow*)d_parent)->toggleRollup();
@@ -234,7 +230,7 @@ void Titlebar::onFontChanged(WindowEventArgs& e)
 {
 	Window::onFontChanged(e);
 
-	if (d_parent != NULL)
+	if (d_parent)
 	{
 		d_parent->performChildWindowLayout();
 	}
@@ -247,26 +243,7 @@ void Titlebar::onFontChanged(WindowEventArgs& e)
 void Titlebar::addTitlebarProperties(void)
 {
 	addProperty(&d_dragEnabledProperty);
-	addProperty(&d_captionColourProperty);
 }
 
 
-/*************************************************************************
-	Return the current colour used for rendering the caption text
-*************************************************************************/
-colour	Titlebar::getCaptionColour(void) const
-{
-	return d_captionColour;
-}
-
-
-/*************************************************************************
-	Sets the colour to be used for rendering the caption text.
-*************************************************************************/
-void Titlebar::setCaptionColour(const colour& col)
-{
-	d_captionColour = col;
-	requestRedraw();
-}
-
 } // End of  CEGUI namespace section
