@@ -1,26 +1,30 @@
-/************************************************************************
+/***********************************************************************
     filename:   CEGUIFalDimensions.cpp
     created:    Mon Jun 13 2005
     author:     Paul D Turner <paul@cegui.org.uk>
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
- 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
- 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
- 
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #include "falagard/CEGUIFalDimensions.h"
 #include "falagard/CEGUIFalXMLEnumHelper.h"
 #include "CEGUIImagesetManager.h"
@@ -148,35 +152,22 @@ namespace CEGUI
         d_operand = operand.clone();
     }
 
-    void BaseDim::writeXMLToStream(OutStream& out_stream) const
+    void BaseDim::writeXMLToStream(XMLSerializer& xml_stream) const
     {
-        // open tag
-        out_stream << "<";
         // get sub-class to output the data for this single dimension
-        writeXMLElementName_impl(out_stream);
-        out_stream << " ";
-        writeXMLElementAttributes_impl(out_stream);
-
+        writeXMLElementName_impl(xml_stream);
+        writeXMLElementAttributes_impl(xml_stream);
         if (d_operand)
         {
-            // terminate the opening element tag
-            out_stream << ">" << std::endl;
             // write out the DimOperator
-            out_stream << "<DimOperator op=\"" << FalagardXMLHelper::dimensionOperatorToString(d_operator) << "\">" << std::endl;
+            xml_stream.openTag("DimOperator")
+                .attribute("op", FalagardXMLHelper::dimensionOperatorToString(d_operator));
             // write out the other operand
-            d_operand->writeXMLToStream(out_stream);
+            d_operand->writeXMLToStream(xml_stream);
             // write closing tag for DimOperator element
-            out_stream << "</DimOperator>" << std::endl;
-            // write closing tag for this dimension element
-            out_stream << "</";
-            writeXMLElementName_impl(out_stream);
-            out_stream << ">" << std::endl;
-        }
-        // no operand, so just close this tag.
-        else
-        {
-            out_stream << " />" << std::endl;
+            xml_stream.closeTag();
         }
+        xml_stream.closeTag();
     }
 
     ////////////////////////////////////////////////////////////////////////////////
@@ -206,14 +197,14 @@ namespace CEGUI
         return ndim;
     }
 
-    void AbsoluteDim::writeXMLElementName_impl(OutStream& out_stream) const
+    void AbsoluteDim::writeXMLElementName_impl(XMLSerializer& xml_stream) const
     {
-        out_stream << "AbsoluteDim";
+        xml_stream.openTag("AbsoluteDim");
     }
 
-    void AbsoluteDim::writeXMLElementAttributes_impl(OutStream& out_stream) const
+    void AbsoluteDim::writeXMLElementAttributes_impl(XMLSerializer& xml_stream) const
     {
-        out_stream << "value=\"" << d_val << "\"";
+        xml_stream.attribute("value", PropertyHelper::floatToString(d_val));
     }
 
 
@@ -297,14 +288,16 @@ namespace CEGUI
         return ndim;
     }
 
-    void ImageDim::writeXMLElementName_impl(OutStream& out_stream) const
+    void ImageDim::writeXMLElementName_impl(XMLSerializer& xml_stream) const
     {
-        out_stream << "ImageDim";
+        xml_stream.openTag("ImageDim");
     }
 
-    void ImageDim::writeXMLElementAttributes_impl(OutStream& out_stream) const
+    void ImageDim::writeXMLElementAttributes_impl(XMLSerializer& xml_stream) const
     {
-        out_stream << "imageset=\"" << d_imageset << "\" image=\"" << d_image << "\" dimension=\"" << FalagardXMLHelper::dimensionTypeToString(d_what) << "\"";
+        xml_stream.attribute("imageset", d_imageset)
+            .attribute("image", d_image)
+            .attribute("dimension", FalagardXMLHelper::dimensionTypeToString(d_what));
     }
 
     ////////////////////////////////////////////////////////////////////////////////
@@ -339,14 +332,17 @@ namespace CEGUI
             widget = WindowManager::getSingleton().getWindow(wnd.getName() + d_widgetName);
         }
 
+        // get size of parent; required to extract pixel values
+        Size parentSize(widget->getParentPixelSize());
+
         switch (d_what)
         {
             case DT_WIDTH:
-                return widget->getAbsoluteWidth();
+                return widget->getPixelSize().d_width;
                 break;
 
             case DT_HEIGHT:
-                return widget->getAbsoluteHeight();
+                return widget->getPixelSize().d_height;
                 break;
 
             case DT_X_OFFSET:
@@ -361,20 +357,20 @@ namespace CEGUI
 
             case DT_LEFT_EDGE:
             case DT_X_POSITION:
-                return widget->getAbsolutePosition().d_x;
+                return widget->getPosition().d_x.asAbsolute(parentSize.d_width);
                 break;
 
             case DT_TOP_EDGE:
             case DT_Y_POSITION:
-                return widget->getAbsolutePosition().d_y;
+                return widget->getPosition().d_y.asAbsolute(parentSize.d_height);
                 break;
 
             case DT_RIGHT_EDGE:
-                return widget->getAbsoluteRect().d_right;
+                return widget->getArea().d_max.d_x.asAbsolute(parentSize.d_width);
                 break;
 
             case DT_BOTTOM_EDGE:
-                return widget->getAbsoluteRect().d_bottom;
+                return widget->getArea().d_max.d_y.asAbsolute(parentSize.d_height);
                 break;
 
             default:
@@ -395,17 +391,17 @@ namespace CEGUI
         return ndim;
     }
 
-    void WidgetDim::writeXMLElementName_impl(OutStream& out_stream) const
+    void WidgetDim::writeXMLElementName_impl(XMLSerializer& xml_stream) const
     {
-        out_stream << "WidgetDim";
+        xml_stream.openTag("WidgetDim");
     }
 
-    void WidgetDim::writeXMLElementAttributes_impl(OutStream& out_stream) const
+    void WidgetDim::writeXMLElementAttributes_impl(XMLSerializer& xml_stream) const
     {
         if (!d_widgetName.empty())
-            out_stream << "widget=\"" << d_widgetName << "\" ";
+            xml_stream.attribute("widget", d_widgetName);
 
-        out_stream << "dimension=\"" << FalagardXMLHelper::dimensionTypeToString(d_what) << "\"";
+        xml_stream.attribute("dimension", FalagardXMLHelper::dimensionTypeToString(d_what));
     }
 
     ////////////////////////////////////////////////////////////////////////////////
@@ -424,7 +420,7 @@ namespace CEGUI
         // get window to use.
         const Window& sourceWindow = d_childSuffix.empty() ? wnd : *WindowManager::getSingleton().getWindow(wnd.getName() + d_childSuffix);
         // get font to use
-        const Font* fontObj = d_font.empty() ? sourceWindow.getFont() : FontManager::getSingleton().getFont(d_font);
+        Font* fontObj = d_font.empty() ? sourceWindow.getFont() : FontManager::getSingleton().getFont(d_font);
 
         if (fontObj)
         {
@@ -462,33 +458,35 @@ namespace CEGUI
         return ndim;
     }
 
-    void FontDim::writeXMLElementName_impl(OutStream& out_stream) const
+    void FontDim::writeXMLElementName_impl(XMLSerializer& xml_stream) const
     {
-        out_stream << "FontDim";
+        xml_stream.openTag("FontDim");
     }
 
-    void FontDim::writeXMLElementAttributes_impl(OutStream& out_stream) const
+    void FontDim::writeXMLElementAttributes_impl(XMLSerializer& xml_stream) const
     {
         if (!d_childSuffix.empty())
-            out_stream << "widget=\"" << d_childSuffix << "\" ";
+            xml_stream.attribute("widget", d_childSuffix);
 
         if (!d_font.empty())
-            out_stream << "font=\"" << d_font << "\" ";
+            xml_stream.attribute("font", d_font);
 
         if (!d_text.empty())
-            out_stream << "string=\"" << d_text << "\" ";
+            xml_stream.attribute("string", d_text);
 
         if (d_padding != 0)
-            out_stream << "padding=\"" << d_padding << "\" ";
+            xml_stream.attribute("padding", PropertyHelper::floatToString(d_padding));
 
-        out_stream << "type=\"" << FalagardXMLHelper::fontMetricTypeToString(d_metric) << "\"";
+        xml_stream.attribute("type", FalagardXMLHelper::fontMetricTypeToString(d_metric));
     }
 
     ////////////////////////////////////////////////////////////////////////////////
 
-    PropertyDim::PropertyDim(const String& name, const String& property) :
+    PropertyDim::PropertyDim(const String& name, const String& property,
+	    DimensionType type) :
         d_property(property),
-        d_childSuffix(name)
+        d_childSuffix(name),
+		d_type (type)
     {
     }
 
@@ -496,8 +494,25 @@ namespace CEGUI
     {
         // get window to use.
         const Window& sourceWindow = d_childSuffix.empty() ? wnd : *WindowManager::getSingleton().getWindow(wnd.getName() + d_childSuffix);
-        // return property value.
-        return PropertyHelper::stringToFloat(sourceWindow.getProperty(d_property));
+
+        if (d_type == DT_INVALID)
+            // return float property value.
+            return PropertyHelper::stringToFloat(sourceWindow.getProperty(d_property));
+
+        UDim d = PropertyHelper::stringToUDim(sourceWindow.getProperty(d_property));
+        Size s = sourceWindow.getPixelSize();
+
+        switch (d_type)
+        {
+            case DT_WIDTH:
+                return d.asAbsolute(s.d_width);
+
+            case DT_HEIGHT:
+                return d.asAbsolute(s.d_height);
+
+            default:
+                throw InvalidRequestException("PropertyDim::getValue - unknown or unsupported DimensionType encountered.");
+        }
     }
 
     float PropertyDim::getValue_impl(const Window& wnd, const Rect& container) const
@@ -507,21 +522,22 @@ namespace CEGUI
 
     BaseDim* PropertyDim::clone_impl() const
     {
-        PropertyDim* ndim = new PropertyDim(d_childSuffix, d_property);
+        PropertyDim* ndim = new PropertyDim(d_childSuffix, d_property, d_type);
         return ndim;
     }
 
-    void PropertyDim::writeXMLElementName_impl(OutStream& out_stream) const
+    void PropertyDim::writeXMLElementName_impl(XMLSerializer& xml_stream) const
     {
-        if (!d_childSuffix.empty())
-            out_stream << "widget=\"" << d_childSuffix << "\" ";
-
-        out_stream << "PropertyDim";
+        xml_stream.openTag("PropertyDim");
     }
 
-    void PropertyDim::writeXMLElementAttributes_impl(OutStream& out_stream) const
+    void PropertyDim::writeXMLElementAttributes_impl(XMLSerializer& xml_stream) const
     {
-        out_stream << "name=\"" << d_property << "\"";
+        if (!d_childSuffix.empty())
+            xml_stream.attribute("widget", d_childSuffix);
+        xml_stream.attribute("name", d_property);
+        if (d_type != DT_INVALID)
+            xml_stream.attribute("type", FalagardXMLHelper::dimensionTypeToString(d_type));
     }
 
     ////////////////////////////////////////////////////////////////////////////////
@@ -558,7 +574,7 @@ namespace CEGUI
         d_value = other.d_value ? other.d_value->clone() : 0;
         d_type = other.d_type;
 
-		return *this;
+        return *this;
     }
 
     const BaseDim& Dimension::getBaseDimension() const
@@ -585,14 +601,14 @@ namespace CEGUI
         d_type = type;
     }
 
-    void Dimension::writeXMLToStream(OutStream& out_stream) const
+    void Dimension::writeXMLToStream(XMLSerializer& xml_stream) const
     {
-        out_stream << "<Dim type=\"" << FalagardXMLHelper::dimensionTypeToString(d_type) << "\">" << std::endl;
+        xml_stream.openTag("Dim")
+            .attribute("type", FalagardXMLHelper::dimensionTypeToString(d_type));
 
         if (d_value)
-            d_value->writeXMLToStream(out_stream);
-
-        out_stream << "</Dim>" << std::endl;
+            d_value->writeXMLToStream(xml_stream);
+        xml_stream.closeTag();
     }
 
     ////////////////////////////////////////////////////////////////////////////////
@@ -612,7 +628,7 @@ namespace CEGUI
             case DT_X_POSITION:
             case DT_X_OFFSET:
             case DT_WIDTH:
-                return d_value.asAbsolute(wnd.getAbsoluteWidth());
+                return d_value.asAbsolute(wnd.getPixelSize().d_width);
                 break;
 
             case DT_TOP_EDGE:
@@ -620,7 +636,7 @@ namespace CEGUI
             case DT_Y_POSITION:
             case DT_Y_OFFSET:
             case DT_HEIGHT:
-                return d_value.asAbsolute(wnd.getAbsoluteHeight());
+                return d_value.asAbsolute(wnd.getPixelSize().d_height);
                 break;
 
             default:
@@ -661,20 +677,20 @@ namespace CEGUI
         return ndim;
     }
 
-    void UnifiedDim::writeXMLElementName_impl(OutStream& out_stream) const
+    void UnifiedDim::writeXMLElementName_impl(XMLSerializer& xml_stream) const
     {
-        out_stream << "UnifiedDim";
+        xml_stream.openTag("UnifiedDim");
     }
 
-    void UnifiedDim::writeXMLElementAttributes_impl(OutStream& out_stream) const
+    void UnifiedDim::writeXMLElementAttributes_impl(XMLSerializer& xml_stream) const
     {
         if (d_value.d_scale != 0)
-            out_stream << "scale=\"" << d_value.d_scale << "\" ";
+            xml_stream.attribute("scale", PropertyHelper::floatToString(d_value.d_scale));
 
         if (d_value.d_offset != 0)
-            out_stream << "offset=\"" << d_value.d_offset << "\" ";
+            xml_stream.attribute("offset", PropertyHelper::floatToString(d_value.d_offset));
 
-        out_stream << "type=\"" << FalagardXMLHelper::dimensionTypeToString(d_what) << "\"";
+        xml_stream.attribute("type", FalagardXMLHelper::dimensionTypeToString(d_what));
     }
 
     ////////////////////////////////////////////////////////////////////////////////
@@ -686,7 +702,7 @@ namespace CEGUI
         // use a property?
         if (isAreaFetchedFromProperty())
         {
-            pixelRect = PropertyHelper::stringToURect(wnd.getProperty(d_areaProperty)).asAbsolute(wnd.getAbsoluteSize());
+            pixelRect = PropertyHelper::stringToURect(wnd.getProperty(d_areaProperty)).asAbsolute(wnd.getPixelSize());
         }
         // not via property - calculate using Dimensions
         else
@@ -721,7 +737,7 @@ namespace CEGUI
         // use a property?
         if (isAreaFetchedFromProperty())
         {
-            pixelRect = PropertyHelper::stringToURect(wnd.getProperty(d_areaProperty)).asAbsolute(wnd.getAbsoluteSize());
+            pixelRect = PropertyHelper::stringToURect(wnd.getProperty(d_areaProperty)).asAbsolute(wnd.getPixelSize());
         }
         // not via property - calculate using Dimensions
         else
@@ -749,24 +765,26 @@ namespace CEGUI
         return pixelRect;
     }
 
-    void ComponentArea::writeXMLToStream(OutStream& out_stream) const
+    void ComponentArea::writeXMLToStream(XMLSerializer& xml_stream) const
     {
-        out_stream << "<Area>" << std::endl;
+        xml_stream.openTag("Area");
 
         // see if we should write an AreaProperty element
         if (isAreaFetchedFromProperty())
         {
-            out_stream << "<AreaProperty name=\"" << d_areaProperty << "\" />" << std::endl;
+            xml_stream.openTag("AreaProperty")
+                .attribute("name", d_areaProperty)
+                .closeTag();
         }
         // not a property, write out individual dimensions explicitly.
         else
         {
-            d_left.writeXMLToStream(out_stream);
-            d_top.writeXMLToStream(out_stream);
-            d_right_or_width.writeXMLToStream(out_stream);
-            d_bottom_or_height.writeXMLToStream(out_stream);
+            d_left.writeXMLToStream(xml_stream);
+            d_top.writeXMLToStream(xml_stream);
+            d_right_or_width.writeXMLToStream(xml_stream);
+            d_bottom_or_height.writeXMLToStream(xml_stream);
         }
-        out_stream << "</Area>" << std::endl;
+        xml_stream.closeTag();
     }
 
     bool ComponentArea::isAreaFetchedFromProperty() const
