@@ -1,26 +1,30 @@
-/************************************************************************
+/***********************************************************************
     filename:   CEGUIFalFrameComponent.cpp
     created:    Mon Jul 18 2005
     author:     Paul D Turner <paul@cegui.org.uk>
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
- 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
- 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
- 
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #include "falagard/CEGUIFalFrameComponent.h"
 #include "falagard/CEGUIFalXMLEnumHelper.h"
 #include "CEGUIImage.h"
@@ -82,7 +86,7 @@ namespace CEGUI
         {
             d_frameImages[part] = &ImagesetManager::getSingleton().getImageset(imageset)->getImage(image);
         }
-        catch (UnknownObjectException)
+        catch (UnknownObjectException&)
         {
             d_frameImages[part] = 0;
         }
@@ -93,6 +97,7 @@ namespace CEGUI
         Rect backgroundRect(destRect);
         Rect finalRect;
         Size imageSize;
+        Vector2 imageOffsets;
         ColourRect imageColours;
         float leftfactor, rightfactor, topfactor, bottomfactor;
         bool calcColoursPerImage;
@@ -122,22 +127,24 @@ namespace CEGUI
         {
             // calculate final destination area
             imageSize = d_frameImages[FIC_TOP_LEFT_CORNER]->getSize();
+            imageOffsets = d_frameImages[FIC_TOP_LEFT_CORNER]->getOffsets();
             finalRect.d_left = destRect.d_left;
             finalRect.d_top  = destRect.d_top;
             finalRect.setSize(imageSize);
+            finalRect = destRect.getIntersection (finalRect);
 
             // update adjustments required to edges do to presence of this element.
-            topOffset  += imageSize.d_width;
-            leftOffset += imageSize.d_height;
+            topOffset  += imageSize.d_width + imageOffsets.d_x;
+            leftOffset += imageSize.d_height + imageOffsets.d_y;
             topWidth   -= topOffset;
             leftHeight -= leftOffset;
 
             // calculate colours that are to be used to this component image
             if (calcColoursPerImage)
             {
-                leftfactor   = (finalRect.d_left + d_frameImages[FIC_TOP_LEFT_CORNER]->getOffsetX()) / destRect.getWidth();
+                leftfactor   = (finalRect.d_left + imageOffsets.d_x) / destRect.getWidth();
                 rightfactor  = leftfactor + finalRect.getWidth() / destRect.getWidth();
-                topfactor    = (finalRect.d_top + d_frameImages[FIC_TOP_LEFT_CORNER]->getOffsetY()) / destRect.getHeight();
+                topfactor    = (finalRect.d_top + imageOffsets.d_y) / destRect.getHeight();
                 bottomfactor = topfactor + finalRect.getHeight() / destRect.getHeight();
 
                 imageColours = finalColours.getSubRectangle( leftfactor, rightfactor, topfactor, bottomfactor);
@@ -152,21 +159,23 @@ namespace CEGUI
         {
             // calculate final destination area
             imageSize = d_frameImages[FIC_TOP_RIGHT_CORNER]->getSize();
+            imageOffsets = d_frameImages[FIC_TOP_RIGHT_CORNER]->getOffsets();
             finalRect.d_left = destRect.d_right - imageSize.d_width;
             finalRect.d_top  = destRect.d_top;
             finalRect.setSize(imageSize);
+            finalRect = destRect.getIntersection (finalRect);
 
             // update adjustments required to edges do to presence of this element.
-            rightOffset += imageSize.d_height;
-            topWidth    -= imageSize.d_width;
+            rightOffset += imageSize.d_height + imageOffsets.d_y;
+            topWidth    -= imageSize.d_width - imageOffsets.d_x;
             rightHeight -= rightOffset;
 
             // calculate colours that are to be used to this component image
             if (calcColoursPerImage)
             {
-                leftfactor   = (finalRect.d_left + d_frameImages[FIC_TOP_RIGHT_CORNER]->getOffsetX()) / destRect.getWidth();
+                leftfactor   = (finalRect.d_left + imageOffsets.d_x) / destRect.getWidth();
                 rightfactor  = leftfactor + finalRect.getWidth() / destRect.getWidth();
-                topfactor    = (finalRect.d_top + d_frameImages[FIC_TOP_RIGHT_CORNER]->getOffsetY()) / destRect.getHeight();
+                topfactor    = (finalRect.d_top + imageOffsets.d_y) / destRect.getHeight();
                 bottomfactor = topfactor + finalRect.getHeight() / destRect.getHeight();
 
                 imageColours = finalColours.getSubRectangle( leftfactor, rightfactor, topfactor, bottomfactor);
@@ -181,21 +190,23 @@ namespace CEGUI
         {
             // calculate final destination area
             imageSize = d_frameImages[FIC_BOTTOM_LEFT_CORNER]->getSize();
+            imageOffsets = d_frameImages[FIC_BOTTOM_LEFT_CORNER]->getOffsets();
             finalRect.d_left = destRect.d_left;
             finalRect.d_top  = destRect.d_bottom - imageSize.d_height;
             finalRect.setSize(imageSize);
+            finalRect = destRect.getIntersection (finalRect);
 
             // update adjustments required to edges do to presence of this element.
-            bottomOffset += imageSize.d_width;
+            bottomOffset += imageSize.d_width + imageOffsets.d_x;
             bottomWidth  -= bottomOffset;
-            leftHeight   -= imageSize.d_height;
+            leftHeight   -= imageSize.d_height - imageOffsets.d_y;
 
             // calculate colours that are to be used to this component image
             if (calcColoursPerImage)
             {
-                leftfactor   = (finalRect.d_left + d_frameImages[FIC_BOTTOM_LEFT_CORNER]->getOffsetX()) / destRect.getWidth();
+                leftfactor   = (finalRect.d_left + imageOffsets.d_x) / destRect.getWidth();
                 rightfactor  = leftfactor + finalRect.getWidth() / destRect.getWidth();
-                topfactor    = (finalRect.d_top + d_frameImages[FIC_BOTTOM_LEFT_CORNER]->getOffsetY()) / destRect.getHeight();
+                topfactor    = (finalRect.d_top + imageOffsets.d_y) / destRect.getHeight();
                 bottomfactor = topfactor + finalRect.getHeight() / destRect.getHeight();
 
                 imageColours = finalColours.getSubRectangle( leftfactor, rightfactor, topfactor, bottomfactor);
@@ -210,13 +221,15 @@ namespace CEGUI
         {
             // calculate final destination area
             imageSize = d_frameImages[FIC_BOTTOM_RIGHT_CORNER]->getSize();
+            imageOffsets = d_frameImages[FIC_BOTTOM_RIGHT_CORNER]->getOffsets();
             finalRect.d_left = destRect.d_right - imageSize.d_width;
             finalRect.d_top  = destRect.d_bottom - imageSize.d_height;
             finalRect.setSize(imageSize);
+            finalRect = destRect.getIntersection (finalRect);
 
             // update adjustments required to edges do to presence of this element.
-            bottomWidth -= imageSize.d_width;
-            rightHeight -= imageSize.d_height;
+            bottomWidth -= imageSize.d_width - imageOffsets.d_x;
+            rightHeight -= imageSize.d_height - imageOffsets.d_y;
 
             // calculate colours that are to be used to this component image
             if (calcColoursPerImage)
@@ -242,6 +255,7 @@ namespace CEGUI
             finalRect.d_right  = finalRect.d_left + topWidth;
             finalRect.d_top    = destRect.d_top;
             finalRect.d_bottom = finalRect.d_top + imageSize.d_height;
+            finalRect = destRect.getIntersection (finalRect);
 
             // adjust background area to miss this edge
             backgroundRect.d_top += imageSize.d_height + d_frameImages[FIC_TOP_EDGE]->getOffsetY();;
@@ -270,6 +284,7 @@ namespace CEGUI
             finalRect.d_right  = finalRect.d_left + bottomWidth;
             finalRect.d_bottom = destRect.d_bottom;
             finalRect.d_top    = finalRect.d_bottom - imageSize.d_height;
+            finalRect = destRect.getIntersection (finalRect);
 
             // adjust background area to miss this edge
             backgroundRect.d_bottom -= imageSize.d_height - d_frameImages[FIC_BOTTOM_EDGE]->getOffsetY();;
@@ -298,6 +313,7 @@ namespace CEGUI
             finalRect.d_right  = finalRect.d_left + imageSize.d_width;
             finalRect.d_top    = destRect.d_top + leftOffset;
             finalRect.d_bottom = finalRect.d_top + leftHeight;
+            finalRect = destRect.getIntersection (finalRect);
 
             // adjust background area to miss this edge
             backgroundRect.d_left += imageSize.d_width + d_frameImages[FIC_LEFT_EDGE]->getOffsetX();
@@ -326,6 +342,7 @@ namespace CEGUI
             finalRect.d_bottom = finalRect.d_top + rightHeight;
             finalRect.d_right  = destRect.d_right;
             finalRect.d_left   = finalRect.d_right - imageSize.d_width;
+            finalRect = destRect.getIntersection (finalRect);
 
             // adjust background area to miss this edge
             backgroundRect.d_right -= imageSize.d_width - d_frameImages[FIC_RIGHT_EDGE]->getOffsetX();
@@ -481,44 +498,50 @@ namespace CEGUI
         }
     }
 
-    void FrameComponent::writeXMLToStream(OutStream& out_stream) const
+    void FrameComponent::writeXMLToStream(XMLSerializer& xml_stream) const
     {
         // opening tag
-        out_stream << "<FrameComponent>" << std::endl;
+        xml_stream.openTag("FrameComponent");
         // write out area
-        d_area.writeXMLToStream(out_stream);
+        d_area.writeXMLToStream(xml_stream);
 
         // write images
         for (int i = 0; i < FIC_FRAME_IMAGE_COUNT; ++i)
         {
             if (d_frameImages[i])
             {
-                out_stream << "<Image imageset=\"" << d_frameImages[i]->getImagesetName();
-                out_stream << "\" image=\"" << d_frameImages[i]->getName();
-                out_stream << "\" type=\"" << FalagardXMLHelper::frameImageComponentToString(static_cast<FrameImageComponent>(i));
-                out_stream << "\" />" << std::endl;
+                xml_stream.openTag("Image")
+                    .attribute("imageset", d_frameImages[i]->getImagesetName())
+                    .attribute("image", d_frameImages[i]->getName())
+                    .attribute("type", FalagardXMLHelper::frameImageComponentToString(static_cast<FrameImageComponent>(i)))
+                    .closeTag();
             }
         }
 
         // get base class to write colours
-        writeColoursXML(out_stream);
+        writeColoursXML(xml_stream);
 
         // write vert format, allowing base class to do this for us if a propety is in use
-        if (!writeVertFormatXML(out_stream))
+        if (!writeVertFormatXML(xml_stream))
         {
             // was not a property, so write out explicit formatting in use
-            out_stream << "<VertFormat type=\"" << FalagardXMLHelper::vertFormatToString(d_vertFormatting) << "\" />" << std::endl;
+            xml_stream.openTag("VertFormat")
+                .attribute("type", FalagardXMLHelper::vertFormatToString(d_vertFormatting))
+                .closeTag();
+
         }
 
         // write horz format, allowing base class to do this for us if a propety is in use
-        if (!writeHorzFormatXML(out_stream))
+        if (!writeHorzFormatXML(xml_stream))
         {
             // was not a property, so write out explicit formatting in use
-            out_stream << "<HorzFormat type=\"" << FalagardXMLHelper::horzFormatToString(d_horzFormatting) << "\" />" << std::endl;
+            xml_stream.openTag("HorzFormat")
+                .attribute("type", FalagardXMLHelper::horzFormatToString(d_horzFormatting))
+                .closeTag();
         }
 
         // closing tag
-        out_stream << "</FrameComponent>" << std::endl;
+        xml_stream.closeTag();
     }
 
 } // End of  CEGUI namespace section
