@@ -44,29 +44,35 @@ namespace CEGUI
 
     WidgetLookManager::WidgetLookManager()
     {
-        Logger::getSingleton().logEvent("CEGUI::WidgetLookManager singleton created.");
+        char addr_buff[32];
+        sprintf(addr_buff, "(%p)", static_cast<void*>(this));
+        Logger::getSingleton().logEvent("CEGUI::WidgetLookManager singleton "
+            "created. " + String(addr_buff));
     }
 
     WidgetLookManager::~ WidgetLookManager()
     {
-        Logger::getSingleton().logEvent("CEGUI::WidgetLookManager singleton destroyed.");
+        char addr_buff[32];
+        sprintf(addr_buff, "(%p)", static_cast<void*>(this));
+        Logger::getSingleton().logEvent("CEGUI::WidgetLookManager singleton "
+            "destroyed. " + String(addr_buff));
     }
 
     /*************************************************************************
-		Return singleton object
-	  *************************************************************************/
-	  WidgetLookManager&	WidgetLookManager::getSingleton(void)
-	  {
-		  return Singleton<WidgetLookManager>::getSingleton();
-	  }
+        Return singleton object
+      *************************************************************************/
+      WidgetLookManager&    WidgetLookManager::getSingleton(void)
+      {
+          return Singleton<WidgetLookManager>::getSingleton();
+      }
 
-	  /*************************************************************************
-		  Return singleton pointer
-	  *************************************************************************/
-	  WidgetLookManager*	WidgetLookManager::getSingletonPtr(void)
-	  {
-		  return Singleton<WidgetLookManager>::getSingletonPtr();
-  	}
+      /*************************************************************************
+          Return singleton pointer
+      *************************************************************************/
+      WidgetLookManager*    WidgetLookManager::getSingletonPtr(void)
+      {
+          return Singleton<WidgetLookManager>::getSingletonPtr();
+    }
 
     void WidgetLookManager::parseLookNFeelSpecification(const String& filename, const String& resourceGroup)
     {
